import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='bookkeeping Get in on IGTS asap.',
    from_='baocqccyw@hq.lindsayelec.com',
    to=('em-ca-bruceg@em.ca',),
    cc=(),
    bcc=(),
    reply_to=('baocqccyw@hq.lindsayelec.com',),
    date=datetime.datetime(2005, 3, 27, 19, 11, 59, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=64800))),
    date_str='Sun, 27 Mar 2005 19:11:59 -0600',
    text='acidness\r\n\r\n          Exciting Easter Investor Alert\r\n\r\nTicker:IGTS\r\nCurrent:0.01\r\nRating:Big Mover Next Week\r\n\r\nThis st0ck receives our top rating - 10 out of 10\r\nBreaking NEWS (released last night): Intelligent\r\n\r\nSports, Inc. Offers Affordable Alternative\r\nThis is the first news release the company put\r\nout since November - this is going to be exciting\r\nstock play\r\n\r\nJump on board while you can - Don\'t regret It later\r\n\r\nAbout the Company:\r\n\r\nYouth And Amateur Sports Company Poised For Growth \r\n\r\nIntelligent Sports, Inc. is a publicly held company\r\ntrading on the OTC markets under the ticker symbol\r\nIGTS. Intelligent Sports will be the holding company\r\nfor several sports related businesses. Intelligent\r\nSports provides business units with strategic guidance\r\nand support in the areas of marketing, sales,\r\nsponsorships, partnerships, policy & procedures,\r\nfinance and expansion. Their initial business launch\r\nis to develop youth and amateur sports centers\r\nthroughout the country that offers a year-round\r\nsports calendar with emphasis on youth and amateur\r\nsports programs and skill development. Their plan\r\nis to expand this concept into membership-based,\r\nmulti-purpose sports facilities that will promote\r\na diverse range of sports programs, leagues,\r\ntournaments, clinics, individual sports skill\r\ndevelopment and nutritional training.\r\n\r\nFresh News:\r\n\r\nUPLAND, Calif., Mar 22, 2005 (PRIMEZONE via COMTEX)\r\nParticipation fees for school sports programs\r\ncontinues to escalate, at the same time record\r\nobesity levels in children are being reported by\r\nthe Center for Disease Control. Intelligent Sports,\r\nInc. (Pink Sheets:IGTS) is working to do their part\r\nto curb this alarming trend of by offering affordable\r\nfitness centers to kids. \r\n\r\n"The time when school sports programs had enrollment\r\nfees of $10 is fading," said former NBA star and\r\nIntelligent Sports, Inc. board member, Reggie Theus.\r\n"Not every parent is willing to pay $300 enrollment\r\nfees for a sport their child is only casually\r\ninterested in; some parents can\'t afford to pay that\r\nmuch for a sport their child excels at."\r\n\r\nAccording to the President\'s Council on Physical\r\nFitness and Sports, only 17 percent of middle and\r\njunior high schools and 2 percent of senior high\r\nschools require daily physical activity for all\r\nstudents. Hoping to fill the gap, The Sports Zone\r\nby Intelligent Sports will support a wide range of\r\nmembership-based after-school sports programs,\r\nweekend leagues and tournaments promoting individual\r\nathletic skill development, the concepts of teamwork\r\nand discipline, and a love of the game.\r\n\r\nThe Sports Zone opened in early October in Upland,\r\nCalifornia. It encompasses a 10,000 square foot\r\nfacility featuring two basketball courts and caters\r\nto court sports including basketball, volleyball,\r\ncheerleading, and wrestling, and also has the ability\r\nto host soccer, football and other field-related\r\nathletic activity within the complex arena.\r\n\r\n+++++++++++++++++++++++++++\r\nIGTS is expected to Explode All Next Week Be Sure\r\nTo Get It Immediately, and profit big!\r\n++++++++++++++++++++++++++++\r\n\r\nDisclaimer\r\n\r\nThis publication is not registered investment advisor,\r\nThe information presented above is not an offer to\r\nbuy or sell securities it contains "forward looking\r\nstatements" within the meaning of Section 27A of the\r\nSecurities Act of 1933 and Section 21B of the\r\nSecurities Exchange Act of 1934. Any statements that\r\nexpress or involve discussions with respect to\r\npredictions, goals, expectations, beliefs, plans,\r\nprojections, objectives, assumptions or future events\r\nor performance are not statements of historical fact\r\nand may be "forward looking statements." In compliance\r\nwith Section 17(b), the publishers of this report\r\ndisclose the holding of IGTS shares prior to the\r\npublication of this report. Be aware of an inherent\r\nconflict of interest resulting from such holdings\r\ndue to our intent to profit from the liquidation\r\nof these shares. Shares may be sold at any time,\r\neven after positive statements have been made\r\nregarding the above company. Since we own shares,\r\nthere is an inherent conflict of interest in our\r\nstatements and opinions. Readers of this publication\r\nare cautioned not to place undue reliance on forward\r\nlooking statements, which are based on certain\r\nassumptions and expectations involving various risks\r\nand uncertainties, that could cause results to differ\r\nmaterially from those set forth in the forward- looking\r\nstatements. Please be advised that nothing within this\r\nemail shall constitute a solicitation or an offer to\r\nbuy or sell any security mentioned herein. This newsletter\r\nis neither a registered investment advisor nor affiliated\r\nwith any broker or dealer. All statements made are our\r\nexpress opinion only and should be treated as such. We\r\nmay own, buy and sell any securities mentioned at any\r\ntime. This report includes forward-looking statements\r\nwithin the meaning of The Private Securities Litigation\r\nReform Act of 1995. This newsletter was paid\r\n41 500, from third party to send this report. Please do\r\nyour own diligence before investing in any profiled company.\r\nYou may lose money from investing. caddis worktable\r\n',
    html='',
    headers={'return-path': ('<baocqccyw@hq.lindsayelec.com>', '<baocqccyw@hq.lindsayelec.com>'), 'delivered-to': ('em-ca-bruceg-spam@em.ca', 'em-ca-em-ca-bruceg@em.ca'), 'received': ('(qmail 32184 invoked by uid 700); 28 Mar 2005 01:14:54 -0000', '(qmail 32179 invoked by uid 115); 28 Mar 2005 01:14:54 -0000', 'from baocqccyw@hq.lindsayelec.com by churchill by uid 64011 with qmail-scanner-1.22 \r\n (clamdscan: 0.75-1. spamassassin: 2.63.  Clear:RC:0(200.141.184.56):. \r\n Processed in 10.454045 secs); 28 Mar 2005 01:14:54 -0000', 'from dial.suednet.com.br (HELO hq.lindsayelec.com) (200.141.184.56)\r\n  by churchill.factcomp.com with SMTP; 28 Mar 2005 01:14:42 -0000'), 'from': ('shavonda Cabral <baocqccyw@hq.lindsayelec.com>',), 'to': ('<em-ca-bruceg@em.ca>',), 'subject': ('bookkeeping Get in on IGTS asap.',), 'date': ('Sun, 27 Mar 2005 19:11:59 -0600',), 'reply-to': ('<baocqccyw@hq.lindsayelec.com>',), 'mime-version': ('1.0',), 'x-virus-status': ('Scanned by norton',), 'message-id': ('<41314357824.13240873.93296@oxygen-k19.hq.lindsayelec.com>',), 'content-type': ('text/plain; charset=us-ascii',), 'content-transfer-encoding': ('plain',), 'content-length': ('5102',), 'lines': ('125',)},
    attachments=[],
    from_values=EmailAddress(name='shavonda Cabral', email='baocqccyw@hq.lindsayelec.com'),
    to_values=(EmailAddress(name='', email='em-ca-bruceg@em.ca'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='', email='baocqccyw@hq.lindsayelec.com'),),
)


from imap_tools import MailBox

# get size of message and attachments
with MailBox('imap.my.ru').login('acc', 'pwd', 'INBOX') as mailbox:
    for msg in mailbox.fetch():
        print(msg.date_str, msg.subject)
        print('-- RFC822.SIZE message size', msg.size_rfc822)
        print('-- bytes size', msg.size)  # will returns headers size only when fetch headers_only=True
        for att in msg.attachments:
            print('---- ATT:', att.filename)
            print('-- bytes size', att.size)



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Saying Hello',
    from_='jdoe@machine.example',
    to=('mary@example.net',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1997, 11, 21, 9, 55, 6, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=64800))),
    date_str='Fri, 21 Nov 1997 09:55:06 -0600',
    text='This is a message just to say hello.\r\nSo, "Hello".\r\n',
    html='',
    headers={'resent-from': ('Mary Smith <mary@example.net>',), 'resent-to': ('Jane Brown <j-brown@other.example>',), 'resent-date': ('Mon, 24 Nov 1997 14:22:01 -0800',), 'resent-message-id': ('<78910@example.net>',), 'from': ('John Doe <jdoe@machine.example>',), 'to': ('Mary Smith <mary@example.net>',), 'subject': ('Saying Hello',), 'date': ('Fri, 21 Nov 1997 09:55:06 -0600',), 'message-id': ('<1234@local.machine.example>',)},
    attachments=[],
    from_values=EmailAddress(name='John Doe', email='jdoe@machine.example'),
    to_values=(EmailAddress(name='Mary Smith', email='mary@example.net'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Formao FrenetikPolis: Mega Campanha Final Vero | Cursos de Setembro',
    from_='info@formacaofrenetik.info',
    to=('martin@internet.ao', 'iris@internet.ao', 'support@maxnet.ao'),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='TEST\r\n',
    html='',
    headers={'from': ('"=?Windows-1252?B?Rm9ybWHn428gRnJlbmV0aWtwb2xpcw==?=" <info@formacaofrenetik.info>',), 'to': ('martin@internet.ao, iris@internet.ao, support@maxnet.ao',), 'subject': ('Forma\udce7\udce3o FrenetikPolis: Mega Campanha Final Ver\udce3o | Cursos de Setembro',)},
    attachments=[],
    from_values=EmailAddress(name='Formação Frenetikpolis', email='info@formacaofrenetik.info'),
    to_values=(EmailAddress(name='', email='martin@internet.ao'), EmailAddress(name='', email='iris@internet.ao'), EmailAddress(name='', email='support@maxnet.ao')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='',
    from_='pete@silly.example',
    to=('c@a.test', 'joe@where.test', 'jdoe@one.test'),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1969, 2, 13, 23, 32, 54, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=73800))),
    date_str='Thu, 13 Feb 1969 23:32:54 -0330',
    text='Testing.\r\n',
    html='',
    headers={'from': ('Pete <pete@silly.example>',), 'to': ('A Group:Chris Jones <c@a.test>,joe@where.test,John <jdoe@one.test>;',), 'cc': ('Undisclosed recipients:;',), 'date': ('Thu, 13 Feb 1969 23:32:54 -0330',), 'message-id': ('<testabcd.1234@silly.example>',)},
    attachments=[],
    from_values=EmailAddress(name='Pete', email='pete@silly.example'),
    to_values=(EmailAddress(name='Chris Jones', email='c@a.test'), EmailAddress(name='', email='joe@where.test'), EmailAddress(name='John', email='jdoe@one.test')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='testing',
    from_='foo@example.com',
    to=('blah@example.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2005, 6, 6, 22, 21, 22, tzinfo=datetime.timezone(datetime.timedelta(seconds=7200))),
    date_str='Mon, 6 Jun 2005 22:21:22 +0200',
    text="A fax has arrived from remote ID ''.\r\n------------------------------------------------------------\r\nTime: 3/9/2006 3:50:52 PM\r\nReceived from remote ID: \r\nInbound user ID XXXXXXXXXX, routing code XXXXXXXXX\r\nResult: (0/352;0/0) Successful Send\r\nPage record: 1 - 1\r\nElapsed time: 00:58 on channel 11\r\n\r\n",
    html='',
    headers={'mime-version': ('1.0 (Apple Message framework v730)',), 'message-id': ('<9169D984-4E0B-45EF-82D4-8F5E53AD7012@example.com>',), 'from': ('foo@example.com',), 'subject': ('testing',), 'date': ('Mon, 6 Jun 2005 22:21:22 +0200',), 'to': ('blah@example.com',), 'content-transfer-encoding': ('quoted-printable',), 'content-type': ('text/plain',)},
    attachments=[],
    from_values=EmailAddress(name='', email='foo@example.com'),
    to_values=(EmailAddress(name='', email='blah@example.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import os
import sys
import unittest
import datetime
from tests.utils import MailboxTestCase

from imap_tools import MailMessage, MailMessageFlags, EmailAddress
from imap_tools.consts import PYTHON_VERSION_MINOR


def _load_module(full_path: str):
    module_name = ''
    if sys.version_info.minor >= 5:
        import importlib.util
        spec = importlib.util.spec_from_file_location(module_name, full_path)
        module = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(module)  # noqa
        return module
    else:
        from importlib.machinery import SourceFileLoader
        return SourceFileLoader(module_name, full_path).load_module()  # noqa


class MessageTest(MailboxTestCase):

    def test_live(self):
        none_type = type(None)
        for mailbox in self.mailbox_set.values():
            mailbox.folder.set(mailbox.folder_test_base)
            flag_set = {MailMessageFlags.ANSWERED, MailMessageFlags.FLAGGED}

            # headers_only
            cnt_fetch_all_head = 0
            cnt_fetch_all_head_answered_and_flagged = 0
            for message in mailbox.fetch(headers_only=True):
                if flag_set.issubset(message.flags):
                    cnt_fetch_all_head_answered_and_flagged += 1
                cnt_fetch_all_head += 1
                self.assertEqual(message.text, '')
                self.assertEqual(message.html, '')
                self.assertEqual(len(message.attachments), 0)

            # fetch in bulk
            cnt_fetch_all_bulk = 0
            cnt_fetch_all_bulk_answered_and_flagged = 0
            for message in mailbox.fetch(bulk=True):
                if flag_set.issubset(message.flags):
                    cnt_fetch_all_bulk_answered_and_flagged += 1
                cnt_fetch_all_bulk += 1

            # fetch by one, types
            cnt_fetch_all = 0
            cnt_fetch_all_answered_and_flagged = 0
            for message in mailbox.fetch():
                if flag_set.issubset(message.flags):
                    cnt_fetch_all_answered_and_flagged += 1
                cnt_fetch_all += 1
                self.assertIn(type(message.uid), (str, none_type))
                self.assertIs(type(message.subject), str)
                self.assertIs(type(message.from_), str)
                self.assertIn(type(message.from_values), (EmailAddress, none_type))
                self.assertIs(type(message.date), datetime.datetime)
                self.assertIs(type(message.date_str), str)
                self.assertIs(type(message.text), str)
                self.assertIs(type(message.html), str)
                self.assertIs(type(message.headers), dict)
                self.assertIs(type(message.size_rfc822), int)
                self.assertIs(type(message.size), int)

                for addr_field in {'to', 'cc', 'bcc', 'reply_to'}:
                    self.assertIs(type(getattr(message, addr_field)), tuple)
                    for i in getattr(message, addr_field):
                        self.assertIs(type(i), str)
                    self.assertIs(type(getattr(message, '{}_values'.format(addr_field))), tuple)
                    for i in getattr(message, '{}_values'.format(addr_field)):
                        self.assertIs(type(i), EmailAddress)

                self.assertIs(type(message.flags), tuple)
                for i in message.flags:
                    self.assertIs(type(i), str)

                for att in message.attachments:
                    self.assertIs(type(att.filename), str)
                    self.assertIs(type(att.content_id), str)
                    self.assertIs(type(att.content_type), str)
                    self.assertIs(type(att.content_disposition), str)
                    self.assertIs(type(att.payload), bytes)
                    self.assertIs(type(att.size), int)

            # counts
            self.assertTrue(cnt_fetch_all_answered_and_flagged >= 1)
            self.assertTrue(cnt_fetch_all_head_answered_and_flagged >= 1)
            self.assertTrue(cnt_fetch_all_bulk_answered_and_flagged >= 1)
            self.assertTrue(
                cnt_fetch_all ==
                cnt_fetch_all_head ==
                cnt_fetch_all_bulk ==
                6
            )
            self.assertTrue(
                cnt_fetch_all_answered_and_flagged ==
                cnt_fetch_all_head_answered_and_flagged ==
                cnt_fetch_all_bulk_answered_and_flagged
            )

    def test_attributes(self):
        test_msg_attr_set = {'subject', 'from_', 'to', 'cc', 'bcc', 'reply_to', 'date', 'date_str', 'text', 'html',
                             'headers', 'from_values', 'to_values', 'cc_values', 'bcc_values', 'reply_to_values'}
        test_att_attr_set = {'filename', 'content_id', 'content_type', 'content_disposition', 'payload'}

        eml_path_set = []
        for path_variant in ('../tests/messages', 'tests/messages'):
            for root, subdirs, files in os.walk(path_variant):
                for file_name in files:
                    full_path = os.path.abspath('{}/{}'.format(root, file_name)).replace('\\', '/')
                    if full_path.lower().endswith('.eml'):
                        eml_path_set.append(full_path)

        for eml_path in eml_path_set:
            # *there are many parser improvements at 3.13
            fixed_in_py313 = ('missing_body.eml', 'bad_date_header.eml', 'raw_email_with_at_display_name.eml')
            if any(i in eml_path for i in fixed_in_py313) and PYTHON_VERSION_MINOR == 13:
                continue
            py_path = eml_path.replace('/messages/', '/messages_data/')[:-4] + '.py'
            eml_data_module = _load_module(py_path)
            expected_data = eml_data_module.DATA  # noqa
            with open(eml_path, 'rb') as f:
                bytes_data = f.read()
            message = MailMessage.from_bytes(bytes_data)
            for msg_attr in test_msg_attr_set:
                self.assertEqual(getattr(message, msg_attr), expected_data[msg_attr])
            for att_i, att in enumerate(message.attachments):
                for att_attr in test_att_attr_set:
                    self.assertEqual(getattr(att, att_attr), expected_data['attachments'][att_i][att_attr])


if __name__ == "__main__":
    unittest.main()

"""
attachment_2_base64
    Непонятно почему get_content_type не может получить content-type, в файле он есть
    Из за этого 2е вложение воспринимается как msg.text, хотя в файле его нет
    Возможно это из за наличия дефекта MissingHeaderBodySeparatorDefect
    .../python/Python36-32/Lib/email/message.py 
    def get_content_type(self): 
        ...
        value = self.get('content-type', missing) -> None -> return self.get_default_type() -> text/plain
"""



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Säying Hello',
    from_='jdöe@mächine.example',
    to=('märy@exämple.net',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='body\r\n',
    html='',
    headers={'from': ('"J\udcc3\udcb6hn Doe" <jd\udcc3\udcb6e@m\udcc3\udca4chine.example>',), 'to': ('"M\udcc3\udca4ry Smith" <m\udcc3\udca4ry@ex\udcc3\udca4mple.net>',), 'subject': ('S\udcc3\udca4ying Hello',)},
    attachments=[],
    from_values=EmailAddress(name='Jöhn Doe', email='jdöe@mächine.example'),
    to_values=(EmailAddress(name='Märy Smith', email='märy@exämple.net'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='',
    from_='',
    to=(),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='To    : Mary Smith\r\n__\r\n          <mary@example.net>\r\nSubject     : Saying Hello\r\nDate  : Fri, 21 Nov 1997 09(comment):   55  :  06 -0600\r\nMessage-ID  : <1234   @   local(blah)  .machine .example>\r\n\r\nThis is a message just to say hello.\r\nSo, "Hello".\r\n',
    html='',
    headers={},
    attachments=[],
    from_values=None,
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='',
    from_='shechem@poetrix.com',
    to=('vladi.Pimenov@enron.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2001, 8, 19, 6, 31, 3, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=61200))),
    date_str='Sun, 19 Aug 2001 06:31:03 -0700',
    text='middagh  oldusercompare\r\nothermachine  one-twist  natascha mz05 ntsoft  netvladi.Pimenovr\r\n\r\n\r\nWe supply high quality medications vladi.Pimenovy mail order at very competitive prices\r\nand provide a professional, convenient and affordavladi.Pimenovle means of purchasing\r\nyour presc_ription medicines online\r\nDepresion-an"xiety, Antivladi.Pimenoviotic, Wt Loss, Women\'s Health, Mus-cle Relaxants,\r\nSleeping Aids, Allergies and Paain Relief. Your tastes will vladi.Pimenove met here with\r\n600 medications \r\nHscearpomh http://fi.com.adherentgood.com/?2NX1q/vladi.Pimenoviayimh\r\n\r\n\r\nmore people are using it for quicker rx refill\r\n\r\n\r\nWhen you\'re not with me?Well darling Im telling you now\r\nIm no good without you anyhowAnd have I told you lately that I love you\r\n\r\nOr you and I, If I only had wings of a little angel\r\n\r\n\r\n',
    html='',
    headers={'received': ('from nahou-mscnx06p.corp.enron.com ([192.168.110.237]) by napdx-msmbx01v.corp.enron.com with Microsoft SMTPSVC(5.0.2195.1600);\r\n\t Sun, 19 Aug 2001 04:06:57 -0800', 'from corp.enron.com ([192.168.110.226]) by nahou-mscnx06p.corp.enron.com with Microsoft SMTPSVC(5.0.2195.2966);\r\n\t Sun, 19 Aug 2001 06:06:02 -0600', 'from mailman.enron.com (unverified) by corp.enron.com\r\n (Content Technologies SMTPRS 4.2.1) with ESMTP id <T5a0a080174c0a86ee241c@corp.enron.com> for <vpimenov@exchange.enron.com>;\r\n Sun, 19 Aug 2001 06:04:08 -0600', 'from poetrix.com ([61.146.170.133])\r\n        by mailman.enron.com (8.11.4/8.11.4/corp-1.06) with ESMTP id g343Bbl38716\r\n        for <vladi.Pimenov@enron.com>; Sun, 19 Aug 2001 07:03:27 -0500 (CDT)'), 'message-id': ('<35FDF82F.D000339@poetrix.com>',), 'date': ('Sun, 19 Aug 2001 06:31:03 -0700',), 'from': ('"neal ragland" <shechem@poetrix.com>',), 'user-agent': ('AspMail 3.06',), 'x-accept-language': ('en-us',), 'mime-version': ('1.0',), 'to': ('"palmer vladi.Pimenovraud" <vladi.Pimenov@enron.com>',), 'suvladi.pimenovject': ('For a vladi.Pimenovetter and more promising future just check eke',), 'content-type': ('text/plain;\r\n\tcharset="us-ascii"',), 'content-transfer-encoding': ('7vladi.Pimenovit',)},
    attachments=[],
    from_values=EmailAddress(name='neal ragland', email='shechem@poetrix.com'),
    to_values=(EmailAddress(name='palmer vladi.Pimenovraud', email='vladi.Pimenov@enron.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


"""IMAP Query builder"""
import datetime
import itertools
import functools
from collections import UserString
from typing import Iterable, Optional, Dict, Any, List, Union, Iterator

from .consts import SHORT_MONTH_NAMES
from .utils import clean_uids, quote


class Header:
    """Header value for search by header key"""
    __slots__ = ('name', 'value')

    def __init__(self, name: str, value: str):
        if not isinstance(name, str):
            raise TypeError(f'Header-name expected str value, "{type(name)}" received')
        self.name = quote(name)
        if not isinstance(value, str):
            raise TypeError(f'Header-value expected str value, "{type(value)}" received')
        self.value = quote(value)

    def __str__(self):
        return f'{self.name}: {self.value}'

    def __lt__(self, other):
        return f'{self.name}{self.value}' < f'{other.name}{other.value}'


class UidRange:
    """
    UID range value for search by uid key
    * - represents the largest number in use.
    x:y - represents sequence range, example: 4:*
    NOTE: UID range of <value>:* always includes the UID of the last message in the mailbox,
    even if <value> is higher than any assigned UID value ->
    any UID range with * indicates at least one message (with the highest numbered UID), unless the mailbox is empty.
    """
    __slots__ = ('start', 'end')

    def __init__(self, start: str, end: Optional[str] = None):
        self.start = str(start).strip()
        if not (self.start.isdigit() or self.start == '*'):
            raise TypeError('UidRange start arg must be str with digits or *')
        if end is None:
            self.end = None
        else:
            self.end = str(end).strip()
            if not (self.end.isdigit() or self.end == '*'):
                raise TypeError('UidRange end arg must be str with digits or *')

    def __str__(self):
        return f'{self.start}{f":{self.end}" if self.end else ""}'


class LogicOperator(UserString):
    def __init__(
            self,
            *converted_strings: Union[str, UserString],
            answered: Optional[bool] = None,
            seen: Optional[bool] = None,
            flagged: Optional[bool] = None,
            draft: Optional[bool] = None,
            deleted: Optional[bool] = None,
            keyword: Optional[Union[str, List[str]]] = None,
            no_keyword: Optional[Union[str, List[str]]] = None,
            from_: Optional[Union[str, List[str]]] = None,
            to: Optional[Union[str, List[str]]] = None,
            subject: Optional[Union[str, List[str]]] = None,
            body: Optional[Union[str, List[str]]] = None,
            text: Optional[Union[str, List[str]]] = None,
            bcc: Optional[Union[str, List[str]]] = None,
            cc: Optional[Union[str, List[str]]] = None,
            date: Optional[Union[datetime.date, List[datetime.date]]] = None,
            date_gte: Optional[Union[datetime.date, List[datetime.date]]] = None,
            date_lt: Optional[Union[datetime.date, List[datetime.date]]] = None,
            sent_date: Optional[Union[datetime.date, List[datetime.date]]] = None,
            sent_date_gte: Optional[Union[datetime.date, List[datetime.date]]] = None,
            sent_date_lt: Optional[Union[datetime.date, List[datetime.date]]] = None,
            size_gt: Optional[int] = None,
            size_lt: Optional[int] = None,
            new: Optional[bool] = None,
            old: Optional[bool] = None,
            recent: Optional[bool] = None,
            all: Optional[bool] = None,  # noqa
            uid: Optional[Union[str, Iterable[str], UidRange]] = None,
            header: Optional[Union[Header, List[Header]]] = None,
            gmail_label: Optional[Union[str, List[str]]] = None):
        self.converted_strings = converted_strings
        for val in converted_strings:
            if not any(isinstance(val, t) for t in (str, UserString)):
                raise TypeError(f'Unexpected type "{type(val)}" for converted part, str like obj expected')
        unconverted_dict = {k: v for k, v in locals().items() if k in SEARCH_KEYS and v is not None}
        self.converted_params = ParamConverter(unconverted_dict).convert()
        if not any((self.converted_strings, self.converted_params)):
            raise ValueError(f'{self.__class__.__name__} expects params')
        super().__init__(self.combine_params())

    def combine_params(self) -> str:
        """combine self.converted_strings and self.converted_params to IMAP search criteria format"""
        raise NotImplementedError

    @staticmethod
    def prefix_join(operator: str, params: Iterable[str]) -> str:
        """Join params by prefix notation rules, enclose group in parentheses"""
        return f'({functools.reduce(lambda a, b: f"{operator}{a} {b}", params)})'


class AND(LogicOperator):
    """Combines conditions by logical AND"""

    def combine_params(self) -> str:
        return self.prefix_join('', itertools.chain(self.converted_strings, self.converted_params))


class OR(LogicOperator):
    """Combines conditions by logical OR"""

    def combine_params(self) -> str:
        return self.prefix_join('OR ', itertools.chain(self.converted_strings, self.converted_params))


class NOT(LogicOperator):
    """Inverts the result of a logical expression"""

    def combine_params(self) -> str:
        return f'NOT {self.prefix_join("", itertools.chain(self.converted_strings, self.converted_params))}'


class ParamConverter:
    """Convert search params to IMAP format"""

    multi_key_allowed = (
        'keyword', 'no_keyword', 'from_', 'to', 'subject', 'body', 'text', 'bcc', 'cc',
        'date', 'date_gte', 'date_lt', 'sent_date', 'sent_date_gte', 'sent_date_lt',
        'header', 'gmail_label',
    )

    def __init__(self, params: Dict[str, Any]):
        self.params = params

    def _gen_values(self, key: str, value: Any) -> Iterator[Any]:
        """Values generator"""
        # single value
        if key not in self.multi_key_allowed or isinstance(value, str):
            yield value
        else:
            try:
                # multiple values
                for i in value:
                    yield i
            except TypeError:
                # single value
                yield value

    def convert(self) -> List[str]:
        """
        :return: params in IMAP format
        """
        converted = []
        for key, raw_val in sorted(self.params.items(), key=lambda x: x[0]):
            for val in sorted(self._gen_values(key, raw_val)):
                convert_func = getattr(self, f'convert_{key}', None)
                if not convert_func:
                    raise KeyError(f'"{key}" is an invalid parameter.')
                converted.append(convert_func(key, val))
        return converted

    @classmethod
    def format_date(cls, value: datetime.date) -> str:
        """To avoid locale affects"""
        return f'{value.day}-{SHORT_MONTH_NAMES[value.month - 1]}-{value.year}'

    @staticmethod
    def cleaned_str(key: str, value: str) -> str:
        if type(value) is not str:
            raise TypeError(f'"{key}" expected str value, "{type(value)}" received')
        return str(value)

    @staticmethod
    def cleaned_date(key: str, value: datetime.date) -> datetime.date:
        if type(value) is not datetime.date:
            raise TypeError(f'"{key}" expected datetime.date value, "{type(value)}" received')
        return value

    @staticmethod
    def cleaned_bool(key: str, value: bool) -> bool:
        if type(value) is not bool:
            raise TypeError(f'"{key}" expected bool value, "{type(value)}" received')
        return bool(value)

    @staticmethod
    def cleaned_true(key: str, value: bool) -> True:
        if value is not True:
            raise TypeError(f'"{key}" expected "True", "{type(value)}" received')
        return True

    @staticmethod
    def cleaned_uint(key: str, value: int) -> int:
        if type(value) is not int or int(value) < 0:
            raise TypeError(f'"{key}" expected int value >= 0, "{type(value)}" received')
        return int(value)

    @staticmethod
    def cleaned_uid(key: str, value: Union[str, Iterable[str], UidRange]) -> str:
        # range
        if isinstance(value, UidRange):
            return str(value)
        # set
        try:
            return ','.join(clean_uids(value))
        except TypeError as e:
            raise TypeError(f'{key} parse error: {str(e)}')

    @staticmethod
    def cleaned_header(key: str, value: Header) -> Header:
        if not isinstance(value, Header):
            raise TypeError(f'"{key}" expected Header (H) value, "{type(value)}" received')
        return value

    def convert_answered(self, key, value) -> str:
        """Messages [with/without] the Answered flag set. (ANSWERED, UNANSWERED)"""
        return 'ANSWERED' if self.cleaned_bool(key, value) else 'UNANSWERED'

    def convert_seen(self, key, value) -> str:
        """Messages that [have/do not have] the Seen flag set. (SEEN, UNSEEN)"""
        return 'SEEN' if self.cleaned_bool(key, value) else 'UNSEEN'

    def convert_flagged(self, key, value) -> str:
        """Messages [with/without] the Flagged flag set. (FLAGGED, UNFLAGGED)"""
        return 'FLAGGED' if self.cleaned_bool(key, value) else 'UNFLAGGED'

    def convert_draft(self, key, value) -> str:
        """Messages that [have/do not have] the Draft flag set. (DRAFT, UNDRAFT)"""
        return 'DRAFT' if self.cleaned_bool(key, value) else 'UNDRAFT'

    def convert_deleted(self, key, value) -> str:
        """Messages that [have/do not have] the Deleted flag set. (DELETED, UNDELETED)"""
        return 'DELETED' if self.cleaned_bool(key, value) else 'UNDELETED'

    def convert_keyword(self, key, value) -> str:
        """Messages with the specified keyword flag set. (KEYWORD)"""
        return f'KEYWORD {self.cleaned_str(key, value)}'

    def convert_no_keyword(self, key, value) -> str:
        """Messages that do not have the specified keyword flag set. (UNKEYWORD)"""
        return f'UNKEYWORD {self.cleaned_str(key, value)}'

    def convert_from_(self, key, value) -> str:
        """Messages that contain the specified string in the envelope structure's FROM field."""
        return f'FROM {quote(self.cleaned_str(key, value))}'

    def convert_to(self, key, value) -> str:
        """Messages that contain the specified string in the envelope structure's TO field."""
        return f'TO {quote(self.cleaned_str(key, value))}'

    def convert_subject(self, key, value) -> str:
        """Messages that contain the specified string in the envelope structure's SUBJECT field."""
        return f'SUBJECT {quote(self.cleaned_str(key, value))}'

    def convert_body(self, key, value) -> str:
        """Messages that contain the specified string in the body of the message."""
        return f'BODY {quote(self.cleaned_str(key, value))}'

    def convert_text(self, key, value) -> str:
        """Messages that contain the specified string in the header or body of the message."""
        return f'TEXT {quote(self.cleaned_str(key, value))}'

    def convert_bcc(self, key, value) -> str:
        """Messages that contain the specified string in the envelope structure's BCC field."""
        return f'BCC {quote(self.cleaned_str(key, value))}'

    def convert_cc(self, key, value) -> str:
        """Messages that contain the specified string in the envelope structure's CC field."""
        return f'CC {quote(self.cleaned_str(key, value))}'

    def convert_date(self, key, value) -> str:
        """
        Messages whose internal date (disregarding time and timezone)
        is within the specified date. (ON)
        """
        return f'ON {self.format_date(self.cleaned_date(key, value))}'

    def convert_date_gte(self, key, value) -> str:
        """
        Messages whose internal date (disregarding time and timezone)
        is within or later than the specified date. (SINCE)
        """
        return f'SINCE {self.format_date(self.cleaned_date(key, value))}'

    def convert_date_lt(self, key, value) -> str:
        """
        Messages whose internal date (disregarding time and timezone)
        is earlier than the specified date. (BEFORE)
        """
        return f'BEFORE {self.format_date(self.cleaned_date(key, value))}'

    def convert_sent_date(self, key, value) -> str:
        """
        Messages whose [RFC-2822] Date: header (disregarding time and timezone)
        is within the specified date. (SENTON)
        """
        return f'SENTON {self.format_date(self.cleaned_date(key, value))}'

    def convert_sent_date_gte(self, key, value) -> str:
        """
        Messages whose [RFC-2822] Date: header (disregarding time and timezone)
        is within or later than the specified date. (SENTSINCE)
        """
        return f'SENTSINCE {self.format_date(self.cleaned_date(key, value))}'

    def convert_sent_date_lt(self, key, value) -> str:
        """
        Messages whose [RFC-2822] Date: header (disregarding time and timezone)
        is earlier than the specified date. (SENTBEFORE)
        """
        return f'SENTBEFORE {self.format_date(self.cleaned_date(key, value))}'

    def convert_size_gt(self, key, value) -> str:
        """Messages with an [RFC-2822] size larger than the specified number of octets. (LARGER)"""
        return f'LARGER {self.cleaned_uint(key, value)}'

    def convert_size_lt(self, key, value) -> str:
        """Messages with an [RFC-2822] size smaller than the specified number of octets. (SMALLER)"""
        return f'SMALLER {self.cleaned_uint(key, value)}'

    def convert_new(self, key, value) -> str:
        """
        Messages that have the Recent flag set but not the Seen flag.
        This is functionally equivalent to "(RECENT UNSEEN)".
        """
        self.cleaned_true(key, value)
        return 'NEW'

    def convert_old(self, key, value) -> str:
        """
        Messages that do not have the Recent flag set.
        This is functionally equivalent to "NOT RECENT" (as opposed to "NOT NEW").
        """
        self.cleaned_true(key, value)
        return 'OLD'

    def convert_recent(self, key, value) -> str:
        """Messages that have the Recent flag set."""
        self.cleaned_true(key, value)
        return 'RECENT'

    def convert_all(self, key, value) -> str:
        """All messages in the mailbox; the default initial key for ANDing."""
        self.cleaned_true(key, value)
        return 'ALL'

    def convert_header(self, key, value) -> str:
        """
        Messages that have a header with the specified field-name (as defined in [RFC-2822])
        and that contains the specified string in the text of the header (what comes after the colon).
        If the string to search is zero-length, this matches all messages that have a header line
        with the specified field-name regardless of the contents.
        """
        return f'HEADER {self.cleaned_header(key, value).name} {self.cleaned_header(key, value).value}'

    def convert_uid(self, key, value) -> str:
        """Messages with unique identifiers corresponding to the specified unique identifier set."""
        return f'UID {self.cleaned_uid(key, value)}'

    def convert_gmail_label(self, key, value) -> str:
        return f'X-GM-LABELS {quote(self.cleaned_str(key, value))}'


SEARCH_KEYS = tuple(i.replace('convert_', '') for i in dir(ParamConverter) if 'convert_' in i)

# Short alias set:
A = AND
O = OR  # noqa
N = NOT
H = Header
U = UidRange



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='まみむめも',
    from_='raasdnil@gmail.com',
    to=('raasdnil@gmail.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='すみません。\r\n\r\n',
    html='',
    headers={'mime-version': ('1.0',), 'subject': ('=?UTF-8?B?44G+44G/44KA44KB44KC?=',), 'from': ('Mikel Lindsaar <raasdnil@gmail.com>',), 'to': ('=?UTF-8?B?44G/44GR44KL?= <raasdnil@gmail.com>',), 'content-type': ('text/plain;\r\n charset=iso-2022-jp',), 'content-transfer-encoding': ('7bit',)},
    attachments=[],
    from_values=EmailAddress(name='Mikel Lindsaar', email='raasdnil@gmail.com'),
    to_values=(EmailAddress(name='みける', email='raasdnil@gmail.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Fwd: Signed email causes file attachments',
    from_='xxxxxxxxx.xxxxxxx@gmail.com',
    to=('xxxxx@xxxxxxxxx.com',),
    cc=(),
    bcc=(),
    reply_to=('xxxxxxxxx.xxxxxxx@gmail.com',),
    date=datetime.datetime(2005, 5, 8, 14, 9, 11, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=68400))),
    date_str='Sun, 8 May 2005 14:09:11 -0500',
    text='We should not include these files or vcards as attachments.\r\n\r\n---------- Forwarded message ----------\r\nFrom: xxxxx xxxxxx <xxxxxxxx@xxx.com>\r\nDate: May 8, 2005 1:17 PM\r\nSubject: Signed email causes file attachments\r\nTo: xxxxxxx@xxxxxxxxxx.com\r\n\r\n\r\nHi,\r\n\r\nTest attachments oddly encoded with japanese charset.\r\n\r\n',
    html='',
    headers={'return-path': ('<xxxxxxxxx.xxxxxxx@gmail.com>',), 'message-id': ('<e85734b90505081209eaaa17b@mail.gmail.com>',), 'date': ('Sun, 8 May 2005 14:09:11 -0500',), 'from': ('xxxxxxxxx xxxxxxx <xxxxxxxxx.xxxxxxx@gmail.com>',), 'reply-to': ('xxxxxxxxx xxxxxxx <xxxxxxxxx.xxxxxxx@gmail.com>',), 'to': ('xxxxx xxxx <xxxxx@xxxxxxxxx.com>',), 'subject': ('Fwd: Signed email causes file attachments',), 'in-reply-to': ('<F6E2D0B4-CC35-4A91-BA4C-C7C712B10C13@mac.com>',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed; \r\n\tboundary="----=_Part_5028_7368284.1115579351471"',), 'references': ('<F6E2D0B4-CC35-4A91-BA4C-C7C712B10C13@mac.com>',)},
    attachments=[
        dict(
            filename='01 Quien Te Dij�at. Pitbull.mp3',
            content_id='',
            content_disposition='attachment',
            content_type='application/octet-stream',
            payload=b'0\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x02\xa0\x800\x80\x02\x01\x011\x0b0\t\x06\x05+\x0e\x03\x02\x1a\x05\x000\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x01\x00\x00\xa0\x82\x06\x140\x82\x02\xcd0\x82\x026\xa0\x03\x02\x01\x02\x02\x03\x0e\\\xf90\r\x06\t*\x86H\x86\xf7\r\x01\x01\x04\x05\x000b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x1e\x17\r050329093910Z\x17\r060329093910Z0B1\x1f0\x1d\x06\x03U\x04\x03\x13\x16Thawte Freemail Member1\x1f0\x1d\x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x10smhaunch@mac.com0\x82\x01"0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x82\x01\x0f\x000\x82\x01\n\x02\x82\x01\x01\x00\x9f\xdd\x1d>\xc6\x12\xdc\xb8\xdf1\x8d\xb5\xd4\xe4\x98\xac4\x0b\xcf\x03X>P\x0b\xef\xef\xf4\\\x0f\xa4w/?\xad\x19\xf2\x10qF\xc2\x13B\x0eh4\x07\xaaq\x0b\xbc\xf7\xc7\x12C\xff\xc1\x9f\t\xdf\x88aE\rQ\x05y\x9b\xd3$\xc5\xf3\xfd\xa55WeR\x18-\xa0p',
        ),
        ],
    from_values=EmailAddress(name='xxxxxxxxx xxxxxxx', email='xxxxxxxxx.xxxxxxx@gmail.com'),
    to_values=(EmailAddress(name='xxxxx xxxx', email='xxxxx@xxxxxxxxx.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='xxxxxxxxx xxxxxxx', email='xxxxxxxxx.xxxxxxx@gmail.com'),),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='MySurvey.com:  You have a survey waiting!  91123105',
    from_='carol@mysurvey.com',
    to=('someone@aol.com',),
    cc=(),
    bcc=(),
    reply_to=('carol@reply.mysurvey.com',),
    date=datetime.datetime(2010, 12, 15, 12, 21, 20, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=68400))),
    date_str='Wed, 15 Dec 2010 12:21:20 -0500 ',
    text="You have a survey waiting!\r\n\r\n\r\nTo take the survey:\r\n\r\n\r\n==================================================================\r\nPlease do not reply to this email, as we do not process emails sent to this address. To view FAQ's or to contact us, please go to our http://www.mysurvey.com/index.cfm?action=Main.lobbyGeneral&MyContent=contact page. \r\n==================================================================   \r\nYou received this email because you (or someone in your household) registered to be a MySurvey.com member. Being a MySurvey.com member means receiving periodic email invitations to give your opinions via e-surveys as well as being eligible for special projects and product tests. If you wish to be removed from the MySurvey.com panel, please click here to http://www.mysurvey.com/index.cfm?action=Main.lobbyGeneral&myContent=unsubscribes.\r\n==================================================================\r\n",
    html='<center>\r\nhello world\r\n</center>\r\n<IMG SRC="http://mailcenterus.mysurvey.com/gems_open_tracking.cfm?indid=99323446&cmpid=10000012106&r=9772160&rundate=15-DEC-2010+12%3a15%3a09&z=435ED3AE69D35EB44716E94814CD11A9"border="0" width="1" height="1">\r\n',
    headers={'received': ('from survey1usmta.mysurvey.com (survey1usmta.mysurvey.com [198.178.238.149])\r\n\tby mtain-dh02.r1000.mx.aol.com (Internet Inbound) with ESMTP id 35AF9380001BD\r\n\tfor <jjffddjkl161@aol.com>; Wed, 15 Dec 2010 12:22:13 -0500 (EST)', 'from 172.30.44.41 (172.30.44.57) by survey1usmta.mysurvey.com (PowerMTA(TM) v3.5r15) id h13ska0ko6cn for <jjffddjkl161@aol.com>; Wed, 15 Dec 2010 12:21:20 -0500 (envelope-from <carol-jjffddjkl161=aol.com@mysurvey.com>)'), 'from': ('=?UTF-8?B?TXlTdXJ2ZXk=?=\r\n =?UTF-8?B?LmNvbSAmIEM=?=\r\n =?UTF-8?B?YXJvbCBBZGE=?=\r\n =?UTF-8?B?bXM=?=\r\n <carol@mysurvey.com>',), 'reply-to': ('carol@reply.mysurvey.com',), 'to': ('someone@aol.com',), 'date': ('Wed, 15 Dec 2010 12:21:20 -0500 ',), 'subject': ('=?UTF-8?B?TXlTdXJ2ZXk=?=\r\n =?UTF-8?B?LmNvbTogIFk=?=\r\n =?UTF-8?B?b3UgaGF2ZSA=?=\r\n =?UTF-8?B?YSBzdXJ2ZXk=?=\r\n =?UTF-8?B?IHdhaXRpbmc=?=\r\n =?UTF-8?B?ISAg?=\r\n =?UTF-8?Q?91123105?=\r\n =?UTF-8?B??=\r\n ',), 'mime-version': ('1.0 ',), 'content-type': ('multipart/alternative;boundary="----=_Layout_Part_DC7E1BB5_1105_4DB3_BAE3_2A6208EB099A"',), 'x-aol-global-disposition': ('G',), 'x-aol-scoll-score': ('1:2:376293952:93952408  ',), 'x-aol-scoll-url_count': ('5  ',), 'x-aol-sid': ('3039ac1d41164d08f9453480',), 'x-aol-ip': ('198.178.238.149',), 'x-aol-spf': ('domain : mysurvey.com SPF : pass',)},
    attachments=[],
    from_values=EmailAddress(name='MySurvey.com & Carol Adams', email='carol@mysurvey.com'),
    to_values=(EmailAddress(name='', email='someone@aol.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='', email='carol@reply.mysurvey.com'),),
)


"""
MailBox traffic through proxy servers using https://github.com/Anorov/PySocks
This logic will not be part of imap_tools
"""
import ssl
import socks
from imaplib import IMAP4

from imap_tools import BaseMailBox, MailBoxUnencrypted


class Imap4Proxy(IMAP4):
    def __init__(self,
                 host: str = "",
                 port: int = 143,
                 p_timeout: int = None,
                 p_source_address: tuple = None,
                 p_proxy_type: socks.PROXY_TYPES = socks.HTTP,
                 p_proxy_addr: str = None,
                 p_proxy_port: int = None,
                 p_proxy_rdns=True,
                 p_proxy_username: str = None,
                 p_proxy_password: str = None,
                 p_socket_options: iter = None,
                 ):
        self._host = host
        self._port = port
        self._p_timeout = p_timeout
        self._p_source_address = p_source_address
        self._p_proxy_type = p_proxy_type
        self._p_proxy_addr = p_proxy_addr
        self._p_proxy_port = p_proxy_port
        self._p_proxy_rdns = p_proxy_rdns
        self._p_proxy_username = p_proxy_username
        self._p_proxy_password = p_proxy_password
        self._p_socket_options = p_socket_options
        super().__init__(host, port)

    def _create_socket(self):
        return socks.create_connection(
            dest_pair=(self._host, self._port),
            timeout=self._p_timeout,
            source_address=self._p_source_address,
            proxy_type=self._p_proxy_type,
            proxy_addr=self._p_proxy_addr,
            proxy_port=self._p_proxy_port,
            proxy_rdns=self._p_proxy_rdns,
            proxy_username=self._p_proxy_username,
            proxy_password=self._p_proxy_password,
            socket_options=self._p_socket_options,
        )


class Imap4SslProxy(Imap4Proxy):
    def __init__(self,
                 host: str = "",
                 port: int = 993,
                 keyfile=None,
                 certfile=None,
                 ssl_context=None,
                 p_timeout: int = None,
                 p_source_address: tuple = None,
                 p_proxy_type: socks.PROXY_TYPES = socks.HTTP,
                 p_proxy_addr: str = None,
                 p_proxy_port: int = None,
                 p_proxy_rdns=True,
                 p_proxy_username: str = None,
                 p_proxy_password: str = None,
                 p_socket_options: iter = None,
                 ):
        self._host = host
        self._port = port
        self._p_timeout = p_timeout
        self._p_source_address = p_source_address
        self._p_proxy_type = p_proxy_type
        self._p_proxy_addr = p_proxy_addr
        self._p_proxy_port = p_proxy_port
        self._p_proxy_rdns = p_proxy_rdns
        self._p_proxy_username = p_proxy_username
        self._p_proxy_password = p_proxy_password
        self._p_socket_options = p_socket_options

        if ssl_context is not None and keyfile is not None:
            raise ValueError("ssl_context and keyfile arguments are mutually exclusive")
        if ssl_context is not None and certfile is not None:
            raise ValueError("ssl_context and certfile arguments are mutually exclusive")
        if keyfile is not None or certfile is not None:
            import warnings
            warnings.warn("keyfile and certfile are deprecated, use ssl_context instead", DeprecationWarning, 2)

        if ssl_context is None:
            ssl_context = ssl._create_stdlib_context(certfile=certfile, keyfile=keyfile)  # noqa

        self.keyfile = keyfile
        self.certfile = certfile
        self.ssl_context = ssl_context

        super().__init__(host, port, p_timeout, p_source_address, p_proxy_type, p_proxy_addr, p_proxy_port,
                         p_proxy_rdns, p_proxy_username, p_proxy_password, p_socket_options)

    def _create_socket(self):
        sock = super()._create_socket()
        server_hostname = self.host if ssl.HAS_SNI else None
        return self.ssl_context.wrap_socket(sock, server_hostname=server_hostname)

    def open(self, host='', port=993):
        super().open(host, port)


class MailBoxUnencryptedProxy(MailBoxUnencrypted):
    """Working with the email box through IMAP4 through proxy"""

    def __init__(self,
                 host: str = "",
                 port: int = 143,
                 p_timeout: int = None,
                 p_source_address: tuple = None,
                 p_proxy_type: socks.PROXY_TYPES = socks.HTTP,
                 p_proxy_addr: str = None,
                 p_proxy_port: int = None,
                 p_proxy_rdns=True,
                 p_proxy_username: str = None,
                 p_proxy_password: str = None,
                 p_socket_options: iter = None,
                 ):
        self._host = host
        self._port = port
        self._p_timeout = p_timeout
        self._p_source_address = p_source_address
        self._p_proxy_type = p_proxy_type
        self._p_proxy_addr = p_proxy_addr
        self._p_proxy_port = p_proxy_port
        self._p_proxy_rdns = p_proxy_rdns
        self._p_proxy_username = p_proxy_username
        self._p_proxy_password = p_proxy_password
        self._p_socket_options = p_socket_options
        super().__init__()

    def _get_mailbox_client(self):
        return Imap4Proxy(
            self._host, self._port,
            self._p_timeout, self._p_source_address, self._p_proxy_type, self._p_proxy_addr, self._p_proxy_port,
            self._p_proxy_rdns, self._p_proxy_username, self._p_proxy_password, self._p_socket_options)


class MailBoxProxy(BaseMailBox):
    """Working with the email box through IMAP4 over SSL connection through proxy"""

    def __init__(self,
                 host: str = "",
                 port: int = 993,
                 keyfile=None,
                 certfile=None,
                 ssl_context=None,
                 p_timeout: int = None,
                 p_source_address: tuple = None,
                 p_proxy_type: socks.PROXY_TYPES = socks.HTTP,
                 p_proxy_addr: str = None,
                 p_proxy_port: int = None,
                 p_proxy_rdns=True,
                 p_proxy_username: str = None,
                 p_proxy_password: str = None,
                 p_socket_options: iter = None,
                 ):
        self._host = host
        self._port = port
        self._keyfile = keyfile
        self._certfile = certfile
        self._ssl_context = ssl_context
        self._p_timeout = p_timeout
        self._p_source_address = p_source_address
        self._p_proxy_type = p_proxy_type
        self._p_proxy_addr = p_proxy_addr
        self._p_proxy_port = p_proxy_port
        self._p_proxy_rdns = p_proxy_rdns
        self._p_proxy_username = p_proxy_username
        self._p_proxy_password = p_proxy_password
        self._p_socket_options = p_socket_options
        super().__init__()

    def _get_mailbox_client(self):
        return Imap4SslProxy(
            self._host, self._port, self._keyfile, self._certfile, self._ssl_context,
            self._p_timeout, self._p_source_address, self._p_proxy_type, self._p_proxy_addr, self._p_proxy_port,
            self._p_proxy_rdns, self._p_proxy_username, self._p_proxy_password, self._p_socket_options)


if __name__ == '__main__':
    with MailBoxProxy(p_proxy_type=socks.HTTP,
                      p_proxy_addr='1.2.3.4',  # zproxy.lum-superproxy.io
                      p_proxy_port=3192,  # 22225
                      p_proxy_username='proxy_username',
                      p_proxy_password='proxy_pwd_123',
                      p_timeout=10,
                      host='imap.host.com').login('mail.user', 'mail_pwd_123', 'INBOX') as mailbox:
        for msg in mailbox.fetch():
            print(msg.subject, msg.date_str)



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='40% OFF holiday patterns and fabric!',
    from_='enews@Free-Quilting.com',
    to=('someone@live.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='Wed, 15 Dec 2010    59:10 -0500',
    text='',
    html='',
    headers={'x-message-delivery': ('Vj0xLjE7dXM9MDtsPTA7YT0xO0Q9MTtTQ0w9MA==',), 'x-message-status': ('n',), 'x-sid-pra': ('enews@Free-Quilting.com',), 'x-auth-result': ('NONE',), 'x-message-info': ('JGTYoYF78jHCcITVD+zs6u3ahcolNfp0m61kNO2SBMwKZtwdSoGZLR+eV3xtqv3QU2mvP3b1AtESP6eCYbaI4dABkTSkMMCjZGPGH3Q01dsRSddQ0kCWDw==',), 'received': ('from drg.drgnetwork.com ([63.76.155.39]) by col0-mc2-f14.Col0.hotmail.com with Microsoft SMTPSVC(6.0.3790.4675);\r\n\t Tue, 14 Dec 2010 22:59:10 -0800', 'from SFGAS1.DRGNETWORK.COM (sfgas1.drgnetwork.com [63.76.155.11])\r\n\tby drg.drgnetwork.com (8.13.8/8.13.8) with ESMTP id oBF6xAuc018214\r\n\tfor <someone@live.com>; Wed, 15 Dec 2010 00:59:10 -0600'), 'message-id': ('<201012150659.oBF6xAuc018214@drg.drgnetwork.com>',), 'sender': ('enews@Free-Quilting.com',), 'date': ('Wed, 15 Dec 2010    59:10 -0500',), 'from': ('"Free-Quilting.com" <enews@Free-Quilting.com>',), 'mime-version': ('1.0',), 'to': ('<someone@live.com>',), 'cc': ('',), 'subject': ('40% OFF holiday patterns and fabric!',), 'content-type': ('multipart/alternative; boundary="--PART.BOUNDARY.0001"',), 'return-path': ('bounces@strategicfulfillment.com',), 'x-originalarrivaltime': ('15 Dec 2010 06:59:10.0647 (UTC) FILETIME=[93232C70:01CB9C25]',)},
    attachments=[],
    from_values=EmailAddress(name='Free-Quilting.com', email='enews@Free-Quilting.com'),
    to_values=(EmailAddress(name='', email='someone@live.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


from imap_tools import MailBox

# get all attachments from INBOX and save them to files
with MailBox('imap.my.ru').login('acc', 'pwd', 'INBOX') as mailbox:
    for msg in mailbox.fetch():
        for att in msg.attachments:
            print(att.filename, att.content_type)
            with open('C:/1/{}'.format(att.filename), 'wb') as f:
                f.write(att.payload)



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='статус    ',
    from_='i.kor@company.ru',
    to=('jessica.schmidt@uni.de', 'я你Rabea.Bartölke@uni.de'),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2017, 10, 12, 9, 41, 56, tzinfo=datetime.timezone(datetime.timedelta(seconds=18000))),
    date_str='Thu, 12 Oct 2017 09:41:56 +0500',
    text='\r\nНовый заказ №28922 http://group.company.ru/ru/order/28922/process/\r\nСоздал: \r\nКлиент Ковчег (Гусев Дмитрий)\r\n\r\nСегменты:\r\n\r\n- Москва - Тель-Авив, some-889, 15.03.2018, эконом: (15 взр.)\r\n\r\n- Тель-Авив - Москва, some-890, 22.03.2018, эконом: (15 взр.)',
    html='\r\n\r\n    <!DOCTYPE html PUBLIC \'-//W3C//DTD XHTML 1.0 Strict//EN\' \'http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\'>\r\n    <html xmlns=\'http://www.w3.org/1999/xhtml\' lang=\'ru-ru\'\r\n          xml:lang=\'en-us\'>\r\n    <head>\r\n        <meta content="text/html; charset=utf-8" http-equiv="Content-Type">\r\n        \r\n    </head>\r\n\r\n    <body id=\'body\'>\r\n    \r\n    \r\n        \r\n        <a href="http://group.company.ru/ru/order/28922/process/">\r\n            \r\n            Новый заказ №28922\r\n        </a><br>\r\n\r\n        \r\n        Создал:\r\n        \r\n            Клиент Ковчег\r\n            (Гусев Дмитрий)\r\n        <br><br>\r\n        \r\n        Сегменты: <br>\r\n        <ul>\r\n            \r\n                <li>Москва - Тель-Авив, some-889, 15.03.2018, эконом: (15 взр.)</li>\r\n            \r\n                <li>Тель-Авив - Москва, some-890, 22.03.2018, эконом: (15 взр.)</li>\r\n            \r\n        </ul><br>\r\n        \r\n        \r\n    \r\n\r\n    </body>\r\n    </html>\r\n\r\n',
    headers={'return-path': ('i.kor@company.ru',), 'received': ('from m101.comp.ru (LHLO m101.comp.ru) (192.168.99.101) by m101.comp.ru\r\n with LMTP; Thu, 12 Oct 2017 09:41:57 +0500 (YEKT)', 'from localhost (localhost [127.0.0.1])\r\n\tby m101.comp.ru (Postfix) with ESMTP id 555275B43;\r\n\tThu, 12 Oct 2017 09:41:57 +0500 (YEKT)', 'from m101.comp.ru ([127.0.0.1])\r\n\tby localhost (m101.comp.ru [127.0.0.1]) (amavisd-new, port 10032)\r\n\twith ESMTP id rY6SAtl4piy1; Thu, 12 Oct 2017 09:41:56 +0500 (YEKT)', 'from localhost (localhost [127.0.0.1])\r\n\tby m101.comp.ru (Postfix) with ESMTP id C8F0F5B4B;\r\n\tThu, 12 Oct 2017 09:41:56 +0500 (YEKT)', 'from m101.comp.ru ([127.0.0.1])\r\n\tby localhost (m101.comp.ru [127.0.0.1]) (amavisd-new, port 10026)\r\n\twith ESMTP id kq2wE_i9_8EK; Thu, 12 Oct 2017 09:41:56 +0500 (YEKT)', 'from [192.168.104.80] (notebook26.hades.company [192.168.104.80])\r\n\tby m101.comp.ru (Postfix) with ESMTPSA id 9563A5B44\r\n\tfor <user@company.ru>; Thu, 12 Oct 2017 09:41:56 +0500 (YEKT)'), 'x-spam-flag': ('NO',), 'x-spam-score': ('-2.898',), 'x-spam-level': ('',), 'x-spam-status': ('No, score=-2.898 required=6.6 tests=[ALL_TRUSTED=-1,\r\n\tBAYES_00=-1.9, HTML_MESSAGE=0.001, URIBL_BLOCKED=0.001]\r\n\tautolearn=ham autolearn_force=no',), 'x-virus-scanned': ('amavisd-new at m101.comp.ru',), 'references': ('<20171011085432.15374.20485@web.hades.company>',), 'subject': ('=?UTF-8?B?0YHRgtCw0YLRg9GB?=    ',), 'to': ('Jessica Schmidt <jessica.schmidt@uni.de>,\r\n\t=?iso-8859-1?Q?Rabea=2EBart=F6lke=40uni=2Ede?= <\udcd1\udc8f\udce4\udcbd\udca0Rabea.Bart\udcc3\udcb6lke@uni.de>',), 'from': ('i.kor@company.ru',), 'x-forwarded-message-id': ('<20171011085432.15374.20485@web.hades.company>',), 'message-id': ('<2405271c-86ac-0a65-e50c-d1ebccfcc644@company.ru>',), 'date': ('Thu, 12 Oct 2017 09:41:56 +0500',), 'user-agent': ('Mozilla/5.0 (Windows NT 6.1; WOW64; rv:52.0) Gecko/20100101\r\n Thunderbird/52.4.0',), 'mime-version': ('1.0',), 'in-reply-to': ('<20171011085432.15374.20485@web.hades.company>',), 'content-type': ('multipart/mixed;\r\n boundary="------------BF90926EC9DF73443A6B8F28"',), 'content-language': ('ru',)},
    attachments=[
        dict(
            filename='Contract 25 04 2020.docx',
            content_id='',
            content_disposition='attachment',
            content_type='message/rfc822',
            payload=b'Return-Path: group@company.ru\nReceived: from m101.comp.ru (LHLO m101.comp.ru) (192.168.99.101) by\n m101.comp.ru\n with LMTP; Wed, 11 Oct 2017 13:54:33 +0500 (YEKT)\nReceived: from localhost (localhost [127.0.0.1])\n\tby m101.comp.ru (Postfix) with ESMTP id 04BDE6E3;\n\tWed, 11 Oct 2017 13:54:33 +0500 (YEKT)\nX-Spam-Flag: NO\nX-Spam-Score: -2.899\nX-Spam-Level: \nX-Spam-Status: No, score=-2.899 required=6.6 tests=[ALL_TRUSTED=-1,\n\tBAYES_00=-1.9, HTML_MESSAGE=0.001, RP_MATCHES_RCVD=-0.001,\n\tURIBL_BLOCKED=0.001] autolearn=ham autolearn_force=no\nReceived: from m101.comp.ru ([127.0.0.1])\n\tby localhost (m101.comp.ru [127.0.0.1]) (amavisd-new, port 10032)\n\twith ESMTP id 3N3XVuSw23lT; Wed, 11 Oct 2017 13:54:32 +0500 (YEKT)\nReceived: from localhost (localhost [127.0.0.1])\n\tby m101.comp.ru (Postfix) with ESMTP id 83DB56E6;\n\tWed, 11 Oct 2017 13:54:32 +0500 (YEKT)\nX-Virus-Scanned: amavisd-new at m101.comp.ru\nReceived: from m101.comp.ru ([127.0.0.1])\n\tby localhost (m101.comp.ru [127.0.0.1]) (amavisd-new, port 10026)\n\twith ESMTP id ylUz-3bpEY_5; Wed, 11 Oct 2017 13:54:32 +0500 (YEKT)\nReceived: from web.hades.company (s192-168-99-108.some.ru [192.168.99.108])\n\tby m101.comp.ru (Postfix) with ESMTPSA id 5AE656E3;\n\tWed, 11 Oct 2017 13:54:32 +0500 (YEKT)\nContent-Type: multipart/alternative;\n boundary="===============3693132879591888836=="\nMIME-Version: 1.0\nSubject: =?UTF-8?B?0YHRgtCw0YLRg9GB?=    \nFrom: group@company.ru\nTo: group@company.ru\nDate: Wed, 11 Oct 2017 08:54:32 -0000\nMessage-ID: <20171011085432.15374.20485@web.hades.company>\n\n--===============3693132879591888836==\nContent-Type: text/plain; charset="utf-8"\nMIME-Version: 1.0\nContent-Transfer-Encoding: quoted-printable\n\n=D0=9D=D0=BE=D0=B2=D1=8B=D0=B9 =D0=B7=D0=B0=D0=BA=D0=B0=D0=B7 =E2=84=9628=\n922 http://group.company.ru/ru/order/28922/process/\n=D0=A1=D0=BE=D0=B7=D0=B4=D0=B0=D0=BB:=20\n=D0=9A=D0=BB=D0=B8=D0=B5=D0=BD=D1=82 =D0=9A=D0=BE=D0=B2=D1=87=D0=B5=D0=B3=\n (=D0=93=D1=83=D1=81=D0=B5=D0=B2 =D0=94=D0=BC=D0=B8=D1=82=D1=80=D0=B8=D0=B9=\n)\n\n=D0=A1=D0=B5=D0=B3=D0=BC=D0=B5=D0=BD=D1=82=D1=8B:\n\n- =D0=9C=D0=BE=D1=81=D0=BA=D0=B2=D0=B0 - =D0=A2=D0=B5=D0=BB=D1=8C-=D0=90=D0=\n=B2=D0=B8=D0=B2, some-889, 15.03.2018, =D1=8D=D0=BA=D0=BE=D0=BD=D0=BE=D0=BC=\n: (15 =D0=B2=D0=B7=D1=80.)\n\n- =D0=A2=D0=B5=D0=BB=D1=8C-=D0=90=D0=B2=D0=B8=D0=B2 - =D0=9C=D0=BE=D1=81=D0=\n=BA=D0=B2=D0=B0, some-890, 22.03.2018, =D1=8D=D0=BA=D0=BE=D0=BD=D0=BE=D0=BC=\n: (15 =D0=B2=D0=B7=D1=80.)\n--===============3693132879591888836==\nContent-Type: text/html; charset="utf-8"\nMIME-Version: 1.0\nContent-Transfer-Encoding: quoted-printable\n\n\n\n    <!DOCTYPE html PUBLIC \'-//W3C//DTD XHTML 1.0 Strict//EN\' \'http://www.=\nw3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\'>\n    <html xmlns=3D\'http://www.w3.org/1999/xhtml\' lang=3D\'ru-ru\'\n          xml:lang=3D\'en-us\'>\n    <head>\n        <meta content=3D"text/html; charset=3DUTF-8" http-equiv=3D"Conten=\nt-Type">\n       =20\n    </head>\n\n    <body id=3D\'body\'>\n   =20\n   =20\n       =20\n        <a href=3D"http://group.company.ru/ru/order/28922/process/">\n           =20\n            =D0=9D=D0=BE=D0=B2=D1=8B=D0=B9 =D0=B7=D0=B0=D0=BA=D0=B0=D0=B7=\n =E2=84=9628922\n        </a><br>\n\n       =20\n        =D0=A1=D0=BE=D0=B7=D0=B4=D0=B0=D0=BB:\n       =20\n            =D0=9A=D0=BB=D0=B8=D0=B5=D0=BD=D1=82 =D0=9A=D0=BE=D0=B2=D1=87=\n=D0=B5=D0=B3\n            (=D0=93=D1=83=D1=81=D0=B5=D0=B2 =D0=94=D0=BC=D0=B8=D1=82=D1=80=\n=D0=B8=D0=B9)\n        <br><br>\n       =20\n        =D0=A1=D0=B5=D0=B3=D0=BC=D0=B5=D0=BD=D1=82=D1=8B: <br>\n        <ul>\n           =20\n                <li>=D0=9C=D0=BE=D1=81=D0=BA=D0=B2=D0=B0 - =D0=A2=D0=B5=D0=\n=BB=D1=8C-=D0=90=D0=B2=D0=B8=D0=B2, some-889, 15.03.2018, =D1=8D=D0=BA=D0=BE=\n=D0=BD=D0=BE=D0=BC: (15 =D0=B2=D0=B7=D1=80.)</li>\n           =20\n                <li>=D0=A2=D0=B5=D0=BB=D1=8C-=D0=90=D0=B2=D0=B8=D0=B2 - =D0=\n=9C=D0=BE=D1=81=D0=BA=D0=B2=D0=B0, some-890, 22.03.2018, =D1=8D=D0=BA=D0=BE=\n=D0=BD=D0=BE=D0=BC: (15 =D0=B2=D0=B7=D1=80.)</li>\n           =20\n        </ul><br>\n       =20\n       =20\n   =20\n\n    </body>\n    </html>\n\n\n--===============3693132879591888836==--\n',
        ),
        ],
    from_values=EmailAddress(name='', email='i.kor@company.ru'),
    to_values=(EmailAddress(name='Jessica Schmidt', email='jessica.schmidt@uni.de'), EmailAddress(name='Rabea.Bartölke@uni.de', email='я你Rabea.Bartölke@uni.de')),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


from imap_tools import MailBox

with MailBox('imap.mail.com').login('test@mail.com', 'pwd', 'INBOX') as mailbox:
    criteria = 'ALL'
    found_nums = mailbox.numbers(criteria)
    page_len = 3
    pages = int(len(found_nums) // page_len) + 1 if len(found_nums) % page_len else int(len(found_nums) // page_len)
    for page in range(pages):
        print('page {}'.format(page))
        page_limit = slice(page * page_len, page * page_len + page_len)
        print(page_limit)
        for msg in mailbox.fetch(criteria, bulk=True, limit=page_limit):
            print(' ', msg.date, msg.uid, msg.subject)



import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Sending messages include last little bit',
    from_='tester1@test.com',
    to=('tester2@test.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2009, 12, 2, 22, 39, 33, tzinfo=datetime.timezone(datetime.timedelta(seconds=46800))),
    date_str='Wed, 2 Dec 2009 22:39:33 +1300',
    text="When sending email:\r\n* From Hotmail you get the ads as well.\r\n* From GMail you also get the person's signature.\r\n\r\nI'm curious, and I might do some digging tomorrow as well, to see if its\r\npossible to strip the last little bit (signature/ads) from email messages.\r\n",
    html='<div class="gmail_quote"><div class="gmail_quote"><div>When sending email:</div>* From Hotmail you get the ads as well.<div>* From GMail you also get the person&#39;s signature.</div><div><br></div><div>I\'m curious, and I might do some digging tomorrow as well, to see if its possible to strip the last little bit (signature/ads) from email messages.<br>\r\n\r\n</div></div></div>\r\n',
    headers={'return-path': ('<test@test.com>',), 'received': ('from mail-xxx.google.com (mail-xxx.google.com [0.0.0.0])\r\n\tby smtp.test.com (Postfix) with ESMTP id xxxx\r\n\tfor <tester@test.com>; Wed,  2 Dec 2009 09:39:57 +0000 (UTC)', 'by qyk6 with SMTP id 6so3112qyk.3\r\n        for <tester@test.com>; Wed, 02 Dec 2009 01:39:53 -0800 (PST)', 'by 0.0.0.0 with SMTP id xxx.000.0000000000000; Wed, \r\n\t02 Dec 2009 01:39:53 -0800 (PST)'), 'mime-version': ('1.0',), 'in-reply-to': ('<8fc5086d0912020131y377ba0ccpf8f14783cfc3014a@test.com>',), 'references': ('<8fc5086d0912020131y377ba0ccpf8f14783cfc3014a@test.com>',), 'from': ('Tester 1 <tester1@test.com>',), 'date': ('Wed, 2 Dec 2009 22:39:33 +1300',), 'message-id': ('<8fc5086d0912020139y1564ad32jb4f4209fa464f4a6@test.com>',), 'subject': ('Sending messages include last little bit',), 'to': ('tester2@test.com',), 'content-type': ('multipart/alternative; boundary=00c09fa216eb1bfc0a0479bba823',)},
    attachments=[],
    from_values=EmailAddress(name='Tester 1', email='tester1@test.com'),
    to_values=(EmailAddress(name='', email='tester2@test.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Пример email с вложением и Content-ID',
    from_='sender@example.com',
    to=('recipient@example.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='текстовое сообщение с вложением, у которого есть Content-ID.\r\n',
    html='',
    headers={'from': ('sender@example.com',), 'to': ('recipient@example.com',), 'subject': ('\udcd0\udc9f\udcd1\udc80\udcd0\udcb8\udcd0\udcbc\udcd0\udcb5\udcd1\udc80 email \udcd1\udc81 \udcd0\udcb2\udcd0\udcbb\udcd0\udcbe\udcd0\udcb6\udcd0\udcb5\udcd0\udcbd\udcd0\udcb8\udcd0\udcb5\udcd0\udcbc \udcd0\udcb8 Content-ID',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed; boundary="boundary123"',)},
    attachments=[
        dict(
            filename='example.png',
            content_id='Test0 "漢字" mid1 "漢字" tail2',
            content_disposition='attachment',
            content_type='image/png',
            payload=b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x05\x00\x00\x00\x00\x15\x00\x00\x00\x13w\xc7u\xc0\x00\x00\x00\x12QS\x91+\x90\x98 ',
        ),
        ],
    from_values=EmailAddress(name='', email='sender@example.com'),
    to_values=(EmailAddress(name='', email='recipient@example.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='double_fields',
    from_='kaukinvk@yandex.ru',
    to=('aa@aa.ru', 'bb@aa.ru'),
    cc=('cc@aa.ru', 'dd@aa.ru'),
    bcc=('zz1@aa.ru', 'zz2@aa.ru'),
    reply_to=('foma1@company.ru', 'petr1@company.ru', 'foma2@company.ru', 'petr2@company.ru'),
    date=datetime.datetime(2019, 5, 1, 12, 20),
    date_str='Wed, 01 May 2019 12:20',
    text='',
    html='<div>double_fields</div>',
    headers={'to': ('aa@aa.ru', 'bb@aa.ru', ''), 'cc': ('cc@aa.ru', 'dd@aa.ru'), 'bcc': ('zz1@aa.ru', 'zz2@aa.ru'), 'reply-to': ('=?UTF-8?B?0L/RgNC40LLQtdGC?= <foma1@company.ru>,\r\n =?UTF-8?B?0L/QvtC60LA=?= <petr1@company.ru>', '=?UTF-8?B?0L/RgNC40LLQtdGC?= <foma2@company.ru>,\r\n =?UTF-8?B?0L/QvtC60LA=?= <petr2@company.ru>'), 'from': ('=?utf-8?B?0JrQsNGD0LrQuNC9INCS0LvQsNC00LjQvNC40YA=?= <kaukinvk@yandex.ru>',), 'envelope-from': ('kaukinvk@yandex.ru',), 'subject': ('double_fields',), 'mime-version': ('1.0',), 'date': ('Wed, 01 May 2019 12:20',), 'message-id': ('<8872861556695229@myt5-262fb1897c00.qloud-c.yandex.net>',), 'content-type': ('multipart/mixed;\r\n\tboundary="----==--bound.887287.myt5-262fb1897c00.qloud-c.yandex.net"',), 'return-path': ('kaukinvk@yandex.ru',)},
    attachments=[],
    from_values=EmailAddress(name='Каукин Владимир', email='kaukinvk@yandex.ru'),
    to_values=(EmailAddress(name='', email='aa@aa.ru'), EmailAddress(name='', email='bb@aa.ru')),
    cc_values=(EmailAddress(name='', email='cc@aa.ru'), EmailAddress(name='', email='dd@aa.ru')),
    bcc_values=(EmailAddress(name='', email='zz1@aa.ru'), EmailAddress(name='', email='zz2@aa.ru')),
    reply_to_values=(EmailAddress(name='привет', email='foma1@company.ru'), EmailAddress(name='пока', email='petr1@company.ru'), EmailAddress(name='привет', email='foma2@company.ru'), EmailAddress(name='пока', email='petr2@company.ru')),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Attention',
    from_='nsukijamq@morozstudio.tk',
    to=('cvs@bruce-guenter.dyndns.org',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2005, 6, 29, 22, 57, 10, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=64800))),
    date_str='Wed, 29 Jun 2005 22:57:10 -0600',
    text='Dear Homeowner,\r\n\r\n \r\n\r\nYou have been pre-approved for a $402,000 Home Loan at a 3.45% Fixed Rate.\r\n\r\nThis offer is being extended to you unconditionally and your credit is in no\r\nway a factor.\r\n\r\n \r\n\r\nTo take Advantage of this Limited Time opportunity all\r\n\r\nwe ask is that you visit our Website and complete\r\n\r\nthe 1 minute post Approval Form.\r\n\r\n \r\n\r\nEnter Here <http://www.lending-blocksx.com/index.php?refid=spr>  \r\n\r\n \r\n\r\nSincerely,\r\n\r\n \r\n\r\nEsteban Tanner\r\n\r\nRegional CEO\r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\nTuuuuurn oooooff notiiificatiiiiions heeeeeeere.\r\n<http://www.great-mort-gages.com/rem.php> \r\n\r\n',
    html='<html xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:w="urn:schemas-microsoft-com:office:word" xmlns="http://www.w3.org/TR/REC-html40">\r\n\r\n<head>\r\n<META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=utf-8">\r\n<meta name=Generator content="Microsoft Word 11 (filtered medium)">\r\n<style>\r\n<!--\r\n /* Style Definitions */\r\n p.MsoNormal, li.MsoNormal, div.MsoNormal\r\n\t{margin:0in;\r\n\tmargin-bottom:.0001pt;\r\n\tfont-size:12.0pt;\r\n\tfont-family:"Times New Roman";}\r\na:link, span.MsoHyperlink\r\n\t{color:blue;\r\n\ttext-decoration:underline;}\r\na:visited, span.MsoHyperlinkFollowed\r\n\t{color:purple;\r\n\ttext-decoration:underline;}\r\nspan.EmailStyle17\r\n\t{mso-style-type:personal-compose;\r\n\tfont-family:Arial;\r\n\tcolor:windowtext;}\r\n@page Section1\r\n\t{size:8.5in 11.0in;\r\n\tmargin:1.0in 1.25in 1.0in 1.25in;}\r\ndiv.Section1\r\n\t{page:Section1;}\r\n-->\r\n</style>\r\n\r\n</head>\r\n\r\n<body lang=EN-US link=blue vlink=purple>\r\n\r\n<div class=Section1>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Dear Homeowner,<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>You have been pre-approved for a $402,000 Home Loan at a\r\n3.45% Fixed Rate.<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>This offer is being extended to you unconditionally and your\r\ncredit is in no way a factor.<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>To take Advantage of this Limited Time opportunity all<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>we ask is that you visit our Website and complete<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>the 1 minute post Approval Form.<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><a href="http://www.lending-blocksx.com/index.php?refid=spr">Enter Here</a>\r\n<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Sincerely,<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Esteban Tanner<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Regional CEO<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=3 face="Times New Roman"><span style=\'font-size:\r\n12.0pt\'>Tuuuuurn oooooff notiiificatiiiiions <a\r\nhref="http://mrratenow.com/x/st.html" target="_new">heeeeeeere.</a></span></font><font\r\nsize=2 face=Arial><span style=\'font-size:10.0pt;font-family:Arial\'><o:p></o:p></span></font></p>\r\n\r\n</div>\r\n\r\n</body>\r\n\r\n</html>\r\n',
    headers={'return-path': ('<nsukijamq@morozstudio.tk>',), 'delivered-to': ('cvs@bruce-guenter.dyndns.org',), 'received': ('(qmail 25055 invoked from network); 30 Jun 2005 03:57:11 -0000', 'from localhost (localhost [127.0.0.1])\r\n  by bruce-guenter.dyndns.org ([192.168.1.3]); 30 Jun 2005 03:57:11 -0000', 'from zak.futurequest.net ([127.0.0.1])\r\n  by localhost ([127.0.0.1])\r\n  with SMTP via TCP; 30 Jun 2005 03:57:11 -0000', '(qmail 20286 invoked from network); 30 Jun 2005 03:57:10 -0000', 'from mx-host.dot.tk (unknown [220.173.239.48])\r\n  by zak.futurequest.net ([69.5.6.152])\r\n  with ESMTP via TCP; 30 Jun 2005 03:57:08 -0000'), 'from': ('"Shelby" <nsukijamq@morozstudio.tk>',), 'to': ('<cvs@bruce-guenter.dyndns.org>',), 'subject': ('Attention',), 'date': ('Wed, 29 Jun 2005 22:57:10 -0600',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative;\r\n\tboundary="----26473166335893217"',), 'x-mailer': ('Microsoft Office Outlook, Build 11.0.5510',), 'thread-index': ('AcT9+CUlRgRKMiKZSj+BjT+PHEf8rQ==',), 'x-mimeole': ('Produced By Microsoft MimeOLE V6.00.2800.1106',), 'content-length': ('7044',), 'lines': ('244',)},
    attachments=[],
    from_values=EmailAddress(name='Shelby', email='nsukijamq@morozstudio.tk'),
    to_values=(EmailAddress(name='', email='cvs@bruce-guenter.dyndns.org'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='まみむめもまみむめもまみむめもまみむめもまみむめもまみむめもまみむめもまみむめもまみむめもまみむめも',
    from_='mikel@test.lindsaar.net',
    to=('raasdnil@gmail.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2009, 10, 30, 19, 11, 2, tzinfo=datetime.timezone(datetime.timedelta(seconds=39600))),
    date_str='Fri, 30 Oct 2009 19:11:02 +1100',
    text='',
    html='',
    headers={'delivered-to': ('raasdnil@gmail.com',), 'received': ('by 10.231.12.67 with SMTP id w3cs164325ibw;\r\n        Fri, 30 Oct 2009 01:11:12 -0700 (PDT)', 'by 10.150.44.2 with SMTP id r2mr2367210ybr.77.1256890271939;\r\n        Fri, 30 Oct 2009 01:11:11 -0700 (PDT)', 'from mx1.test.lindsaar.net.au (mx1.test.lindsaar.net.au [210.14.110.240])\r\n        by mx.google.com with ESMTP id 25si7923673gxk.34.2009.10.30.01.11.11;\r\n        Fri, 30 Oct 2009 01:11:11 -0700 (PDT)', 'from [192.168.4.253] (60-241-138-146.static.tpgi.com.au [60.241.138.146])\r\n\t(using TLSv1 with cipher AES128-SHA (128/128 bits))\r\n\t(No client certificate requested)\r\n\t(Authenticated sender: mikel)\r\n\tby mx1.test.lindsaar.net.au (Postfix) with ESMTPSA id 5C0186DD4CD\r\n\tfor <raasdnil@gmail.com>; Fri, 30 Oct 2009 19:11:08 +1100 (EST)'), 'return-path': ('<mikel@test.lindsaar.net>',), 'received-spf': ('neutral (google.com: 210.14.110.240 is neither permitted nor denied by domain of mikel@test.lindsaar.net) client-ip=210.14.110.240;',), 'authentication-results': ('mx.google.com; spf=neutral (google.com: 210.14.110.240 is neither permitted nor denied by domain of mikel@test.lindsaar.net) smtp.mail=mikel@test.lindsaar.net',), 'subject': ('=?utf-8?B?44G+44G/44KA44KB44KC44G+44G/44KA44KB44KC44G+44G/44KA?=\r\n =?utf-8?B?44KB44KC44G+44G/44KA44KB44KC44G+44G/44KA44KB44KC44G+?=\r\n =?utf-8?B?44G/44KA44KB44KC44G+44G/44KA44KB44KC44G+44G/44KA44KB?=\r\n =?utf-8?B?44KC44G+44G/44KA44KB44KC44G+44G/44KA44KB44KC?=',), 'from': ('Mikel Lindsaar <mikel@test.lindsaar.net>',), 'content-type': ('multipart/mixed; boundary=Apple-Mail-6--589811753',), 'message-id': ('<60A112A8-F26C-4E23-95B8-4EB9F139D6A0@test.lindsaar.net>',), 'date': ('Fri, 30 Oct 2009 19:11:02 +1100',), 'to': ('Mikel Lindsaar <raasdnil@gmail.com>',), 'mime-version': ('1.0 (Apple Message framework v1076)',), 'x-mailer': ('Apple Mail (2.1076)',)},
    attachments=[
        dict(
            filename='かきくけこかきくけこかきくけこかきくけこかきくけこ.txt',
            content_id='',
            content_disposition='attachment',
            content_type='text/plain',
            payload=b'this is the data\r\n',
        ),
        ],
    from_values=EmailAddress(name='Mikel Lindsaar', email='mikel@test.lindsaar.net'),
    to_values=(EmailAddress(name='Mikel Lindsaar', email='raasdnil@gmail.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Western Union Swift Money Transfer',
    from_='ceciledwards@sbcglobal.net',
    to=(),
    cc=(),
    bcc=(),
    reply_to=('western.uniontransfer1@hotmail.fr',),
    date=datetime.datetime(2009, 12, 3, 10, 50, 22, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=57600))),
    date_str='Thu, 3 Dec 2009 10:50:22 -0800 (PST)',
    text='Attention Beneficiary:\r\n\xa0\r\nThis is to officially informed you that we have concluded arrangements to effect your payment of $1,500,000.00 United States Dollars through WESTERN UNION Swift Money transfer services today, but the maximum amount you will be receiving every day starting from tomorrow is $5,000.00 as reflected in our transfer system daily until the funds is completely transferred.\r\n\xa0\r\nThis special arrangement is being used to avoid all scrupulous demands by both the states and federal authorities that have previously delayed your payment till date; we shall need your maximum co-operation to ensure that strictness and confidence is maintained to avoid any further delays.You are to discard any request asking you to send money to any agency such as courier company,Bank and Security Agency as there are no such and any money committed their will be regret, so be wise. \r\n\xa0\r\nPlease contact the Accredited WESTERN UNION Agent for the details of your first payment of $5,000 United States Dollars and reconfirm your correct details that you will like the first transfer to be program with such as Receivers Name, destination where you will like the transfer to be send to and your cell phone number for urgent communication if the need arise.\r\nFill your details below for reference purposes:\r\n*NAME OF CUSTOMER: .........\r\n*ADDRESS: ..........\r\n*COUNTRY: .................\r\n*TEL: .....................\r\n*OCCUPATION: ..............\r\n\xa0\r\nRemember your obligation to secure an International Remittance Form as stated in United Nation act of (FRT209) that will help build and renew your transfer file for record keeping as a way of checkmating the present Economics crisis situations.\r\nContact the below Electronic Transfer unit of WESTERN UNION for immediate programing of your first transfer:\r\n\xa0\r\nName: Rev.John Ntepe\r\nMobile:+229 97292685\r\nEmail: (western.union1891@live.fr) or (westerrnunion_2@sify.com)\r\n\r\n\xa0\r\nRegards.\r\nThanks and God Bless.\r\nMrs.Cecil Edward\r\n\r\n\r\n-- \r\nFilter4: This message has been scanned for viruses and\r\ndangerous content by MailScanner, and is\r\nbelieved to be clean.\r\n\r\n',
    html='<table cellspacing="0" cellpadding="0" border="0" ><tr><td valign="top" style="font: inherit;"><span style="font-weight: bold;">Attention Beneficiary:</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">This is to officially informed you that we have concluded arrangements to effect your payment of $1,500,000.00 United States Dollars through WESTERN UNION Swift Money transfer services today, but the maximum amount you will be receiving every day starting from tomorrow is $5,000.00 as reflected in our transfer system daily until the funds is completely transferred.</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">This special arrangement is being used to avoid all scrupulous demands by both the states and federal authorities that have previously delayed your payment\r\n till date; we shall need your maximum co-operation to ensure that strictness and confidence is maintained to avoid any further delays.You are to discard any request asking you to send money to any agency such as courier company,Bank and Security Agency as there are no such and any money committed their will be regret, so be wise. </span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Please contact the Accredited WESTERN UNION Agent for the details of your first payment of $5,000 United States Dollars and reconfirm your correct details that you will like the first transfer to be program with such as Receivers Name, destination where you will like the transfer to be send to and your cell phone number for urgent communication if the need arise.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Fill your details below for reference\r\n purposes:</span><br style="font-weight: bold;"><span style="font-weight: bold;">*NAME OF CUSTOMER: .........</span><br style="font-weight: bold;"><span style="font-weight: bold;">*ADDRESS: ..........</span><br style="font-weight: bold;"><span style="font-weight: bold;">*COUNTRY: ..................</span><br style="font-weight: bold;"><span style="font-weight: bold;">*TEL: .....................</span><br style="font-weight: bold;"><span style="font-weight: bold;">*OCCUPATION: ..............</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Remember your obligation to secure an International Remittance Form as stated in United Nation act of (FRT209) that will help build and renew your transfer file for record keeping as a way of checkmating the present Economics crisis situations.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Contact the\r\n below Electronic Transfer unit of WESTERN UNION for immediate programing of your first transfer:</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Name: Rev.John Ntepe</span><br style="font-weight: bold;"><span style="font-weight: bold;">Mobile:+229 97292685</span><br style="font-weight: bold;"><span style="font-weight: bold;">Email: (western.union1891@live.fr) or (westerrnunion_2@sify.com)</span><br style="font-weight: bold;"><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Regards.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Thanks and God Bless.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Mrs.Cecil Edward</span><br style="font-weight: bold;"><br style="font-weight: bold;"></td></tr></table><br />-- \r\n<br />This message has been scanned for viruses and\r\n<br />dangerous content by\r\n<a href="http://www.mailscanner.info/"><b>MailScanner</b></a>, and is\r\n<br />believed to be clean.\r\n\r\n\r\n',
    headers={'return-path': ('<ceciledwards@sbcglobal.net>',), 'received': ('from murder ([unix socket])\r\n\t by i.aaa.net (Cyrus v2.2.12-Invoca-RPM-2.2.12-6.fc4) with LMTPA;\r\n\t Thu, 03 Dec 2009 10:50:45 -0800', 'from smtp.aaa.org (unknown [10.1.1.254])\r\n\tby i.aaa.net (Postfix) with ESMTP id B789577FFC\r\n\tfor <ccc@aaa.net>; Thu,  3 Dec 2009 10:50:44 -0800 (PST)', 'from imr-f9b5566049f9cb01.prolexic.com (unknown [10.2.2.254])\r\n\tby smtp.aaa.org (Postfix) with ESMTP id 6B026D64546\r\n\tfor <ccc@aaa.net>; Thu,  3 Dec 2009 12:08:32 -0800 (PST)', 'from web82107.mail.mud.yahoo.com (web82107.mail.mud.yahoo.com [209.191.84.220])\r\n\tby imr-f9b5566049f9cb01.prolexic.com (Postfix) with SMTP id 6B5392BA0459\r\n\tfor <ccc@aaa.net>; Thu,  3 Dec 2009 10:50:23 -0800 (PST)', '(qmail 85490 invoked by uid 60001); 3 Dec 2009 18:50:22 -0000', 'from [41.222.192.69] by web82107.mail.mud.yahoo.com via HTTP; Thu, 03 Dec 2009 10:50:22 PST'), 'x-sieve': ('CMU Sieve 2.2',), 'dkim-signature': ('v=1; a=rsa-sha256; c=relaxed/relaxed; d=sbcglobal.net; s=s1024; t=1259866222; bh=aBaCpZTcwSmyoRxhnNZNc5KV/Eb3zHvR3BG0svTu0C0=; h=Message-ID:X-YMail-OSG:Received:X-Mailer:Date:From:Reply-To:Subject:To:MIME-Version:Content-Type; b=cREZCCsrtGfOYR9ckj97DV792GZUX/4Hktzlm5+WBuxdD8Q4XpjRz7dZ1Rei9JOKH8gseoE6KqujBA7EulWGx/XPX5TlDxgO8c2Vk3ae/Qeh38bDJ8MZXRc3dU1w+IMykQyU+qfFKHjkS1sTE7qcmheL1JsTs+BAXtyyqJL+J+4=',), 'domainkey-signature': ('a=rsa-sha1; q=dns; c=nofws;\r\n  s=s1024; d=sbcglobal.net;\r\n  h=Message-ID:X-YMail-OSG:Received:X-Mailer:Date:From:Reply-To:Subject:To:MIME-Version:Content-Type;\r\n  b=nvmIZcXhl5ZMIwmDabz/TSUlgtHH5VdCGrTn1U6/zkGM1pZvwJgq/BMbY+5o+mwlMz78DrUT9TJwfx48JDz8j4swqWh1dlEfztr4S18hgoVt7RqeuIxGOfOEpa6jlzbgE04EQcKy9ePZsSgOv97IH1Oh8HU7MxPUj1KO9NaKsTA=;',), 'message-id': ('<203751.85280.qm@web82107.mail.mud.yahoo.com>',), 'x-ymail-osg': ('M3VWGGoVM1mRrN0VVqOo_OuQD_g7jcvHWnqhUlpmVpXhEVZvd0t2zfR8Zvl5BY34dERYPAO_SdtSjPrdGHXgu8LQ7s1z74yCasGWj5jLvgVb.l8helkzU2RuUVfjxzO5AxztzNz1gt0nMG0iY4LrYoHWj1fvC6iduhm_H7LRUzBa5MezeY8soTyY1i0ugmXCgsAYu3etOBvYfwqnNmJmRBBgrgu7LB5aXqiQFTWhxKirD7cQrygLK3QPv7r4utOXt2viJDLFBgITADv.ZMOV5HL7VexNpvTIgDDxfYhDLy8F.h8nTquqIYSUUv5eMZUSbEml.QvSrtj5tjuryeWcIFTL6bHTwDBKNq_0gcEZWWbF_g6XiTjcGPVNDlVXVzni3DMOlt8_cscWGy95q_y2ArbGRrJLO5.0OQPdi6uxNIN.qXGwlijACJTlnpd1_k._CkT5_ivRiof0WAcmszBifAA8PLImnre40_vLQfGQN3cN0QfyYgv_dgVaXBhwkeuBfnthQugsAUbBcifuS7ymi37vSSTYpJ.nuHinkBsm8fVBr3FXNGZXB.YtpcxSSbvhimTtoZviodhD7zG2a1oE.X0GUT6FmsnUwVZPZkw0n_17m9.SSe8Qok8YXc9xfTKJyQAtn2yoMrS5.zMMhoQ8h26dmiXyv2N7V5SjOBYCc7ynqi7H6yPWe7FHQls_arY8vzF8xiC1THpiXJkiN4JHScNPk8aVxwY8L278d3RwSdTKa6CjDw1eIxu9XanW.eB0x3t6_VmuNcDRjhTG022kURXkA6x.UuCrKdP0eiVnSXFI0KiI9Xzhg1AMoiMPZRYDQneEPkgtMw.PJePhfVrOo.svKrGzuk5dG6PDHIqTSmd8MwlhZ56eTsDrakeo3ooVoRW_4oi9vyc7LVaJ32shn5mD5RwNyKhPHvzCAVCc3tc_AwkNqoEehTKOaxWuZc_jVuVB4bjJZsXPGeDqh\r\n FuKqBNQHUzr8v6AeX3grpz3M_0jE2qPES2GbJEItyat4WrVzA4SerkByWZHS9xNj.j_xbqdnVznbAdftUA4GFjQMZZql1KgFqrOHnhNkp6Z1QO7IQjCDaVwTATJ5h5uEFbKdmr1QPmmFNbFQub.HwmfikVgWNBn90wUKS2CsJf2IEOHSOicDzIMoC6PWzjCXGGZHZMRcSmtaIXkZ4UYELtiQQCBRgZWh7mhV6wjjbxLE0xv5.lKPSsLzql8COylkhrnoVF2jckLWroGXHsFtEQ5qD2nhDmN.ZlJJ01c1BdE2rGCKbKNfh9qvqXYA0kt9TsfO.H_sp7NWKZmFVnVrGbszkg6xXs4Bo1ITBjxzITVenK_WwO_YPXUV2cHNAXFP88bhiRvKSS31GxaT12QR4RHrWqe0ZjkgfoO.jK9ysUx3NnVSmiDzmnENJAoYbO1Sf8JDVj5yDSCyMxvL4iI7xUBHIzq.lpr6yk1IRkE5074pxlITkHejyzljPbzIUF6OWg95Edlro_QjIQHGeEE1EzNE_JrscrjDYX6mW40CCLFu7ImZVuFmwxC11sC5MIj4KUp8TYSNj2n0WVcTt4jXzSOB4eOlRxtE9dDo3wACeEXc_dzD2BjIOpfUYnIUw2xgRN7wFpd4z6EQ2g3eEv6ny7x9sd0SEh36xG0ZC0juI7Qp0Rj6_1A_YBiIY0AODUdtV1vVuWLTq82Fj0xOhH7I5c03ZYRcJoQBpuc4GDnU.wCi3n.eb1_oHaocDz0E6b6UkpGBB.2d1SXx6BOVu1DEdm6KSg3BUeDld.GzUOUKtWbzyOYdPdedcTa4gljnujUb5tCkjpgEmz_iP0GCs7SYbTcj6AIQxAliexrcdQeNxqxS7hlNOwQmsSGyjufJ7Xrq_NnTp8cWCNUhgmtb4r_gcUjOnPJoz.YpZ8asjZ.uZOgHXpmPIsZL1gozfp_rqYzkx3NYJ8S47IMD84Fa3iVco5SWXVlUx\r\n pF_rRHgvkNQtdMaVU5YZdEGr6OlG.CTrAlZa0IoZ0HgFtB_Lg_',), 'x-mailer': ('YahooMailClassic/8.1.6 YahooMailWebService/0.8.100.260964',), 'date': ('Thu, 3 Dec 2009 10:50:22 -0800 (PST)',), 'from': ('Cecil Edwards <ceciledwards@sbcglobal.net>',), 'reply-to': ('western.uniontransfer1@hotmail.fr',), 'subject': ('Western Union Swift Money Transfer',), 'to': ('undisclosed recipients: ;',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative; boundary="0-2052022825-1259866222=:85280"',), 'x-csi-mailscanner-information': ('Please contact the ISP for more information',), 'x-csi-mailscanner': ('Found to be clean',), 'x-csi-mailscanner-spamcheck': ('spam, ORDB-RBL',), 'x-csi-mailscanner-from': ('ceciledwards@sbcglobal.net',), 'x-spam-status': ('Yes',)},
    attachments=[],
    from_values=EmailAddress(name='Cecil Edwards', email='ceciledwards@sbcglobal.net'),
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='', email='western.uniontransfer1@hotmail.fr'),),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Testing attachments',
    from_='jamis@37signals.com',
    to=('jamis@jamisbuck.org',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2007, 2, 22, 11, 20, 31, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=61200))),
    date_str='Thu, 22 Feb 2007 11:20:31 -0700',
    text='Here is a test of an attachment via email.\r\n\r\n- Jamis\r\n\r\n',
    html='',
    headers={'mime-version': ('1.0 (Apple Message framework v752.3)',), 'message-id': ('<2CCE0408-10C7-4045-9B16-A1C11C31469B@37signals.com>',), 'content-type': ('multipart/signed;\r\n\tmicalg=sha1;\r\n\tboundary=Apple-Mail-42-587703407;\r\n\tprotocol="application/pkcs7-signature"',), 'to': ('Jamis Buck <jamis@jamisbuck.org>',), 'subject': ('Testing attachments',), 'from': ('Jamis Buck <jamis@37signals.com>',), 'date': ('Thu, 22 Feb 2007 11:20:31 -0700',)},
    attachments=[
        dict(
            filename='truncated.png',
            content_id='',
            content_disposition='inline',
            content_type='image/png',
            payload=b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\xa5\x00\x00\x00\xd7\x08\x06\x00\x00\x00{\xc1\x91\x10\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\tpHYs\x00\x00\x0b\x12\x00\x00\x0b\x12\x01\xd2\xdd~\xfc\x00\x00\x00\x17tEXtCreation Time\x001/25/2007\x83\xf4"U\x00\x00\x00\x18tEXtSoftware\x00Adobe FireworksO\xb3\x1fN\x00\x002\x05iTXtXML:com.adobe.xmp<?xpacket begin="\xef\xbb\xbf" id="W5M0MpCehiHzreSzNTczkc9d"?>\n<x:xmpmeta xmlns:x="adobe:ns:meta/" x:xmptk="Adobe XMP Core 4.1-c020 1.255716, Tue Oct 10 2006 23:16:34">\n   <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">\n      <rdf:Description rdf:about=""\n            xmlns:xap="http://ns.adobe.com/xap/1.0/">\n         <xap:CreatorTool>Adobe Fireworks CS3</xap:CreatorTool>\n         <xap:CreateDate>2007-01-25T05:28:21Z</xap:CreateDate>\n         <xap:ModifyDate>2007-01-25T05:28:21Z</xap:ModifyDate>\n      </rdf:Description>\n      <rdf:Description rdf:about=""\n            xmlns:dc="http://purl.org/dc/elements/1.1/">\n         <dc:format>image/png</dc:format>\n      </rdf:Descript\x86\x1a#\xa6i\xc91\xf6\x98\x16d\xa4]h9<`\xa6\x1duc\xfd\xcf@\xb7HR+lFu\xdf\x05\xdek\xa4\xd1Qco\x87\xf9Q\xed$\xb1\x0f*\x01\xca\xb4u\xe9Z^\x17[\x0e2\x8d\x9c_\xb7\x07{}\x90\xe6\xd9bi;\x01\x98\x16b\xa3\xbdjzQ\xdf\nL\xf6\xc49^\xc9A\xf5\xaf\xa4[$\xed5\xbd\x1f:k\x9d\xcca\xdf<PP\x0c\xa7\xac\xcb\'&\x0c\x12\xfb\x0b\x0e[^2\x04\xb9\xc8\xbeI#\xa6\xfc\xb6\'\\6n\xea+\x8f\x12?%`\x16\xfe9O1\xc7W\xfd\x9b\xe7\xb9\xae\x12b`\xaa\xa3\xa3\x9b\xc7~&i\xf9U$[\xdc\\Q\xf7z$sVs\x8e\xcf\x91\n\x9b\xf6\'\xb7H\xb1\x19\x07\xf6j\xc8\x0b,\x8a\xa5\x11c\xe1\xb7\xe6#\x8ceJ\xc7m\xab\x07\x9d\xbf4@\x03\xef\xf4Q\xed\x01\xb2H\xca\xba;n.[j-\x93\x10\x02\x9e\x9f\x9f\x8b$\xd5\xab\x82Vc\x9bu\x1bf\xfb{*\xbc\x80\xd8\x9e[\xe4\x9dcd_$/\xa1\xb3\xbcmY\xab\x1exc\\\xbb\'\xb9\xf6\xd3\x03\x0e\xb7\xd7\xeb\x1bk\x16\xbb\x01\x8f\xd3\xb9\r\xcf~\xf7\xda\xf7\xfam\xfb\xc0\xbc\xb9]}/\xbd~\xdb6z\xe5\xd8\xdf\xb0\xfeGoE\x19\x97e\x9e\x1c\xd5\xe14\xc5\x98\xf2]\xb8\x13\xf6E\xb3M\xb9\xae+N\xa7\x13B\xde\xd7\xcbR\x94\x07@\x07I\xd3\xf9\x01\x94\x18\xbcv`\xed`\xf5^\xf6\x1e0\xed@\xf4xY>\xa3\x17\xe4\xa5\xdb0\x1a\xe7\xd9\xe7\xf1\x9e\xcf\xde{mz\xef\x87\x9f\xc7>\x13\xa7\xf7\xea\xd8vz\xe3\xc7`a\xa0\xb5\x8buj\xd4\x86\xcd>\xad\xcf\xbc4\xcf{6=\x15\xa4HJ;\xe7\xcdj\x9d\x81\xc5\x8d\xf0B`\x8esj\xf9\x9e\xe4\xb4\xe9\xbd\x97c_\xb6\x1d\xbc\x11\x98\xb8lo\xf0{\x92p\xc4\xcf\x93\xaa^;\xfc?\xd7\xe9\xbd\xfc#\xcf\xd1\xcb\x1b\xf1<\x9a\xd7\xeb;\xd0n\x8d\xe1\xf6<\x89\xc7\xe0\xb4\x00\xb5\xf7\xdb\xb4\x04Lyyy\x89Z`$\xf9\xac\xf4\xdb\xfb\x9f\xeb\x02\xad\xba\xb7yJ#\x15\x7f\xa7\xcf!\xab\xaam\x9e\x07`\x0b:\x0f\x8c\x9a\xa7v"\xdfs\xfe\xb2\xe4\rxY\xe0\xc5\x18\xd3\xdc\xb7\x88\x94\xb0\x90U\xd9\xb63,E{\x9b\xcd\xec\xe9\x1az\xddS\xe1\x1c\xa0\xbf\x83\xf2\xf3iOj{\x12Q\xaf\x9e\xb4\xe3rV\x8az\x80\xb5\xf6j\xb1)\xb5\xb2:3\x9e\xd8e\xe7\x87m\n\xab\xfe\xb8\xbe\'!\x8f\xa8ak\x9c\xdf\xe9\xc7\x90g\xe7\xf1\xbd\x07B\x9b\xce`\xb4\x00e@\xda\x9d\xb2l\xde4!!6D\x81\xd6\xabd\xaf\x9c;\xac\x92\x94\xbdw\xae\xeby\x9cV\x8d\xdb{;\xbbt\xa7\xcf\xa7\x91=9\x02\xa1\xcd\xbfV\x9ds\x1d\xf6U\x16\x96|\xecX\x8cT\xb5u\x8a\xac\x8a\xe6\xb9s~8\xb6\x1b8\xdf\x0e\xca\x1d\x94?\x96z\x8eT\x0f\x88z?\x02\xaa\xcd\x03* =-\xabec\x8cUR2\x98\xacd\xb4@\xb3\xbb\x1e=\x90Y\x00r>\x80\x86\xa7\x07\xc2;0?\x9fz`\x1cy\xe5\x1e\xd8\xacZ\xe64\xbd\xe7I\x19\xd6\x9e^4G^__\xa3\x16d\xa9g\xedDu`\xac\r\xc9\xde4\xf3`Psp\xdd\xa6)\x9f;\xfd<d\xd7\xd2\xea=\xe0KM\xf6\xaa\xb5\xac\xe7q{y\x1c\xef\xd4\xfc\xbaG\x87$\x9f\x05\x9f\x17\xa3\xea\xa9r\x95\xb2\xcb\xb24\x0b;.\x97\xcbf\xb5\x91\xe7\xec\xfc\xdf\xa73\xbf\x92\xec\x81\xb9\xfcNXs\xb1t\xd3zV\x12\xb2\xe3l}\x0e\xe5\xc1\x9av#)\xb5 \x7f\r\x9eT\xe42=\xc9\xe890V22?%\x0b\xf6;\xfdx\xea9\x99Vrz`\xf5\xa4\x1f_=\x87F\xaf\x96\x9f\x9cN\xa7\xa8\r\xf2\xd5\xaa\xf1\x1e8{j_\xcb2\xd8za \xa6\xbb-\xf9u\xe4\xd9\x98\xf6\x9dy[\xb0m9\x06\x9a\xe7u3/\x0bt\x11iw3\xb2\x18U\xb0y\xcc\x81\xf6\'\xf3F6\x83\x92n\xad\xe0:\xc0\x16\xac=\xe3\xfb.A?\x8e\xf6L$\x06\x9f\xfe\x0f\xd4\xd9\x17\xa5\x1e\xc8\xac\xbd\xa9\xf9\x16\xac\x1e \x01\xe0?\x07;/\xaf\x06\xc6\xf5C\x00\x00\x00\x00IEND\xaeB`\x82',
        ),
        
        dict(
            filename='smime.p7s',
            content_id='',
            content_disposition='attachment',
            content_type='application/pkcs7-signature',
            payload=b'0\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x02\xa0\x800\x80\x02\x01\x011\x0b0\t\x06\x05+\x0e\x03\x02\x1a\x05\x000\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x01\x00\x00\xa0\x82\x06\'0\x82\x02\xe00\x82\x02I\xa0\x03\x02\x01\x02\x02\x10X\xe7\x14\xd6\x17\xc01\x19Ef9\x12G\xf3\xa2\x950\r\x06\t*\x86H\x86\xf7\r\x01\x01\x05\x05\x000b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x1e\x17\r060912170112Z\x17\r070912170112Z0E1\x1f0\x1d\x06\x03U\x04\x03\x13\x16Thawte Freemail Member1"0 \x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x13jamis@37signals.com0\x82\x01"0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x82\x01\x0f\x000\x82\x01\n\x02\x82\x01\x01\x00\xed\x80\xf4\x97\x8e\x14\x81I\x1b\xac\xfc\xa57\x00\x95\xda\xd9\xdas\x1e\xf9v\xf5\xb4\xda\xdb\x1e\n\x15\xcc\xdf\xd0\x84u\xcc\xe2\xab-\xd8\xc9}\xdd\xc9\x85.3&\xc0n\xcf\xf5\x12^S\x8a\r\xc7\xe8\xd3\xa9Z\x01\x07\xb3U5\xed\x7f\xa3\x9e\x83\xa3B\xa1|\xc6}\x89@\xd0t\xf2\xdb\x91\x93*\xe0A)\x14\xc7f\xe8\xfc\x8c\xdek\x91+\x03\xe1\x8f\xae\xa2\x01g\xbf\xa2\xc0\x9b\xf0:0P\xad\x9f\xeb\xab\xdaG\x1d\x19cC\x10\x1c\x82+\\M6M\xae\x08|\x08H|\xfa\x81.FxZ\x04\xd8\x04s}\xbc\xc7Xy\xadc\x17A\x8e\xe2\n\x86\x93\\*\xc1\xbd\xf2\xc6\xfd\x901\x83\x1b\xc0\x9e\x92#\xe9?f9\x12G\xf3\xa2\x950\x81\x87\x06\x0b*\x86H\x86\xf7\r\x01\t\x10\x02\x0b1x\xa0v0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x10X\xe7\x14\xd6\x17\xc01\x19Ef9\x12G\xf3\xa2\x950\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x04\x82\x01\x00\x9f\xc1\x08\x82\xde\xfe\xbf\xcaW\x91\x0ck\xf7l\x9e\'A\x84>sy\xb3\xdf\xe9\xa7\xddx\xba\xb9M\xf9\x9fzb\xc3\x16Yid]\x98\xbc\xa2\\\xfb\xd4\xf9\x04^\x1e\x94\x9f\xde]\xaa\xb0FL\xde\xc7D\xd1q}y\x1b\xa5\xff\xe4\x13\x14\x97\x035s\x84\x03\x11\xb5\xcc-\x86\xa7?\xbas\xa4k_\x83\xae\xd7c\xf0\x92\x9f\xa96\xb6VM&?\x99\x98\x1d\xa9\xc0+\xba\x93\x81q\x98\xbb\xa8\x18\xe8Y\xcc\xb9\xc1\xbexu\xfb\xd2J:\xe3\x9a\xa2\xdb\x90\x7f\xc4\xf3\x0c?\xea\x01\x90\xb9O\xf1^\x90\x14f\x05+Nd\x07\xac\xd2\x9e!\xd4\xa1\xe6\x80\xe4;\x11Z\x15k\xe7\x99\xbf\x19\xffh\xb1*\xa5\xbfS\x1e\x96\xa9\xa9\xb2\xbc\x1bS\xb3\xfeX\x04Kg\xa5\x93\xa4\xfa\xe5h\xb1\xc6\x04P\x18T\xf85I\xd8\xe4\xafM\xd5\xd2\x8a\xf3-\x05\xd5\xe6\x19;\x06\xdbi>?SFPx\xbf\x03\xb7\xaf\xc4\xf6\x8e\xd2\xe98W\xccr\x8c\xd9M\xe0s\xee\x1a\x99+\x95|\x0f\x00\x00\x00\x00\x00\x00',
        ),
        ],
    from_values=EmailAddress(name='Jamis Buck', email='jamis@37signals.com'),
    to_values=(EmailAddress(name='Jamis Buck', email='jamis@jamisbuck.org'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)


import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Daily Data: D09.ZPH (Averaged data)',
    from_='status@sender.com',
    to=('data@email.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2020, 11, 9, 14, 49, 7, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=57600))),
    date_str='Mon, 09 Nov 2020 14:49:07 -0800 (PST)',
    text='Daily Data: D09.ZPH (Averaged data)\nEmail generated: 10/11/2020 00:04:03.765\nEmail sent: 10/11/2020 00:49:03.125',
    html='',
    headers={'message-id': ('<5fa9c763.1c69fb81.76d95.43d7@mx.google.com>',), 'date': ('Mon, 09 Nov 2020 14:49:07 -0800 (PST)',), 'mime-version': ('1.0',), 'from': ('"Sender" <status@sender.com>',), 'to': ('"Data Email" <data@email.com>',), 'subject': ('Daily Data: D09.ZPH (Averaged data)',), 'content-type': ('multipart/mixed; boundary=--boundary_20_d4727d16-8454-4fa4-9da0-950a95b2c962',)},
    attachments=[
        dict(
            filename='D09.ZPH.txt',
            content_id='',
            content_disposition='',
            content_type='application/octet-stream',
            payload=b'123',
        ),
        ],
    from_values=EmailAddress(name='Sender', email='status@sender.com'),
    to_values=(EmailAddress(name='Data Email', email='data@email.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)